@@ -1,7 +1,7 @@
 <?php
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/index.php $
-$LastChangedRevision: 2436 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/index.php $
+$LastChangedRevision: 2774 $
 */
 
 	// Make sure we display all errors that occur during initialization
@@ -18,11 +18,12 @@ $LastChangedRevision: 2436 $
 	// Use buffering to ensure bogus whitespace in config.php is ignored
 	ob_start(NULL, 2048);
 	$here = dirname(__FILE__);
-	include './textpattern/config.php';
+	include txpath.'/config.php';
 	ob_end_clean();
 
 	include txpath.'/lib/constants.php';
-	if (!isset($txpcfg['txpath']) )	{
+	if (!isset($txpcfg['table_prefix']))
+	{
 		$status = '503 Service Unavailable';
 		if (IS_FASTCGI)
 			header("Status: $status");
@@ -35,6 +36,7 @@ $LastChangedRevision: 2436 $
 		exit ($msg);
 	}
 
-	include $txpcfg['txpath'].'/publish.php';
+	include txpath.'/publish.php';
 	textpattern();
+
 ?>
