@@ -1,7 +1,7 @@
 <?php
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/css.php $
-$LastChangedRevision: 944 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/css.php $
+$LastChangedRevision: 2772 $
 */
 
 if (@ini_get('register_globals'))
@@ -15,8 +15,9 @@ include './config.php';
 ob_end_clean();
 
 $nolog = 1;
+define("txpath", dirname(__FILE__));
 define("txpinterface", "css");
-include $txpcfg['txpath'].'/publish.php';
+include txpath.'/publish.php';
 $s = gps('s');
 $n = gps('n');
 output_css($s,$n);
