@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_admin.php $
-$LastChangedRevision: 2403 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_admin.php $
+$LastChangedRevision: 2729 $
 
 */
 
@@ -33,6 +33,8 @@ $LastChangedRevision: 2403 $
 	{
 		require_privs('admin');
 
+		include_once txpath.'/lib/txplib_admin.php';
+
 		$available_steps = array(
 			'admin',
 			'author_change_pass',
@@ -192,15 +194,15 @@ $LastChangedRevision: 2403 $
 		if ($name && is_valid_email($email))
 		{
 			$password = doSlash(generate_password(6));
-			$nonce = doSlash(md5(uniqid(rand(), true)));
+			$nonce    = doSlash(md5(uniqid(mt_rand(), TRUE)));
 
 			$rs = safe_insert('txp_users', "
-				privs		 = $privs,
-				name		 = '$name',
-				email		 = '$email',
+				privs    = $privs,
+				name     = '$name',
+				email    = '$email',
 				RealName = '$RealName',
-				pass		 =	password(lower('$password')),
-				nonce		 = '$nonce'
+				nonce    = '$nonce',
+				pass     = password(lower('$password'))
 			");
 
 			if ($rs)
@@ -234,70 +236,11 @@ $LastChangedRevision: 2403 $
 		return $levels[$priv];
 	}
 
-// -------------------------------------------------------------
-
-	function send_password($RealName, $name, $email, $password)
-	{
-		global $sitename;
-
-		require_privs('admin.edit');
-
-		$message = gTxt('greeting').' '.$RealName.','.
-
-			"\r\n"."\r\n".gTxt('you_have_been_registered').' '.$sitename.
-
-			"\r\n"."\r\n".gTxt('your_login_is').': '.$name.
-			"\r\n".gTxt('your_password_is').': '.$password.
-
-			"\r\n"."\r\n".gTxt('log_in_at').': '.hu.'textpattern/index.php';
-
-		return txpMail($email, "[$sitename] ".gTxt('your_login_info'), $message);
-	}
-
-// -------------------------------------------------------------
-
-	function send_new_password($password, $email, $name)
-	{
-		global $txp_user, $sitename;
-
-		if ( empty( $name)) $name = $txp_user;
-			
-		$message = gTxt('greeting').' '.$name.','.
-
-			"\r\n"."\r\n".gTxt('your_password_is').': '.$password.
-
-			"\r\n"."\r\n".gTxt('log_in_at').': '.hu.'textpattern/index.php';
-
-		return txpMail($email, "[$sitename] ".gTxt('your_new_password'), $message);
-	}
-
-// -------------------------------------------------------------
-
-	function generate_password($length = 10)
-	{
-		$pass = '';
-		$chars = '023456789bcdfghjkmnpqrstvwxyz';
-		$i = 0;
-
-		while ($i < $length)
-		{
-			$char = substr($chars, mt_rand(0, strlen($chars)-1), 1);
-
-			if (!strstr($pass, $char))
-			{
-				$pass .= $char;
-				$i++;
-			}
-		}
-
-		return $pass;
-	}
-
 // -------------------------------------------------------------
 
 	function new_pass_form()
 	{
-		return '<div style="margin-top: 3em auto auto auto; text-align: center;">'.
+		return '<div style="margin: 3em auto auto auto; text-align: center;">'.
 		form(
 			tag(gTxt('change_password'), 'h3').
 
@@ -349,37 +292,14 @@ $LastChangedRevision: 2403 $
 	{
 		require_privs('admin.edit');
 
-		$name = ps('name');
-
-		$email = safe_field('email', 'txp_users', "name = '".doSlash($name)."'");
-		$new_pass = doSlash(generate_password(6));
-
-		$rs = safe_update('txp_users', "pass = password(lower('$new_pass'))", "name = '".doSlash($name)."'");
-
-		if ($rs)
-		{
-			if (send_new_password($new_pass, $email, $name))
-			{
-				admin(gTxt('password_sent_to').' '.$email);
-			}
-
-			else
-			{
-				admin(gTxt('could_not_mail').' '.$email);
-			}
-		}
-
-		else
-		{
-			admin(gTxt('could_not_update_author').' '.$name);
-		}
+		admin(reset_author_pass(ps('name')));
 	}
 
 // -------------------------------------------------------------
 
 	function change_email_form($email)
 	{
-		return '<div style="margin-top: 3em auto auto auto; text-align: center;">'.
+		return '<div style="margin: 3em auto auto auto; text-align: center;">'.
 		form(
 			tag(gTxt('change_email_address'), 'h3').
 			graf('<label for="new_email">'.gTxt('new_email').'</label> '.
@@ -410,7 +330,7 @@ $LastChangedRevision: 2403 $
 				n.hCell()
 			);
 
-		$rs = safe_rows_start('*', 'txp_users', '1 = 1');
+		$rs = safe_rows_start('*', 'txp_users', '1 = 1 order by name asc');
 
 		if ($rs)
 		{
