@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_css.php $
-$LastChangedRevision: 2403 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_css.php $
+$LastChangedRevision: 2730 $
 */
 
 	if (!defined('txpinterface')) die('txpinterface is undefined.');
@@ -415,20 +415,24 @@ $LastChangedRevision: 2403 $
 
 //-------------------------------------------------------------
 
-	function css_delete() {
-		$name = ps('name');
+	function css_delete()
+	{
+		$name  = ps('name');
+		$count = safe_count('txp_section', "css = '".doSlash($name)."'");
 
-		$default_name = safe_field('css', 'txp_section', "name = 'default'");
-
-		if ($name != $default_name) {
+		if ($count)
+		{
+			$message = gTxt('css_used_by_section', array('{name}' => $name, '{count}' => $count));
+		}
+		
+		else
+		{
 			safe_delete('txp_css', "name = '".doSlash($name)."'");
 
-			css_edit(
-				gTxt('css_deleted', array('{name}' => $name))
-			);
-		} else {
-			echo gTxt('cannot_delete_default_css').'.';
+			$message = gTxt('css_deleted', array('{name}' => $name));
 		}
+		
+		css_edit($message);
 	}
 
 ?>
