@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement 
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_diag.php $
-$LastChangedRevision: 2361 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_diag.php $
+$LastChangedRevision: 2791 $
 
 */
 
@@ -24,48 +24,57 @@ $LastChangedRevision: 2361 $
 	global $files;
 	
 	$files = array(
-		'/include/txp_category.php',
-		'/include/txp_plugin.php',
+		'/../index.php',
+		'/css.php',
+		'/include/txp_admin.php',
+		'/include/txp_article.php',
 		'/include/txp_auth.php',
+		'/include/txp_category.php',
+		'/include/txp_css.php',
+		'/include/txp_diag.php',
+		'/include/txp_discuss.php',
+		'/include/txp_file.php',
 		'/include/txp_form.php',
+		'/include/txp_image.php',
+		'/include/txp_import.php',
+		'/include/txp_link.php',
+		'/include/txp_list.php',
+		'/include/txp_log.php',
+		'/include/txp_page.php',
+		'/include/txp_plugin.php',
+		'/include/txp_prefs.php',
+		'/include/txp_preview.php',
 		'/include/txp_section.php',
 		'/include/txp_tag.php',
-		'/include/txp_list.php',
-		'/include/txp_page.php',
-		'/include/txp_discuss.php',
-		'/include/txp_prefs.php',
-		'/include/txp_log.php',
-		'/include/txp_preview.php',
-		'/include/txp_image.php',
-		'/include/txp_article.php',
-		'/include/txp_css.php',
-		'/include/txp_admin.php',
-		'/include/txp_link.php',
-		'/include/txp_diag.php',
-		'/include/txp_file.php',
-		'/include/txp_import.php',
-		'/lib/admin_config.php',
-		'/lib/txplib_misc.php',
-		'/lib/taglib.php',
-		'/lib/txplib_head.php',
-		'/lib/classTextile.php',
-		'/lib/txplib_html.php',
-		'/lib/txplib_db.php',
+		'/index.php',
 		'/lib/IXRClass.php',
-		'/lib/txplib_forms.php',
+		'/lib/admin_config.php',
 		'/lib/class.thumb.php',
+		'/lib/classTextile.php',
 		'/lib/constants.php',
+		'/lib/taglib.php',
+		'/lib/txplib_admin.php',
+		'/lib/txplib_db.php',
+		'/lib/txplib_forms.php',
+		'/lib/txplib_head.php',
+		'/lib/txplib_html.php',
+		'/lib/txplib_misc.php',
 		'/lib/txplib_update.php',
 		'/lib/txplib_wrapper.php',
-		'/publish/taghandlers.php',
-		'/publish/atom.php',
-		'/publish/log.php',
-		'/publish/comment.php',
-		'/publish/search.php',
-		'/publish/rss.php',
 		'/publish.php',
-		'/index.php',
-		'/css.php',
+		'/publish/atom.php',
+		'/publish/comment.php',
+		'/publish/log.php',
+		'/publish/rss.php',
+		'/publish/search.php',
+		'/publish/taghandlers.php',
+		'/update/_to_1.0.0.php',
+		'/update/_to_4.0.2.php',
+		'/update/_to_4.0.3.php',
+		'/update/_to_4.0.4.php',
+		'/update/_to_4.0.5.php',
+		'/update/_to_4.0.6.php',
+		'/update/_update.php'
 	);
 
 	if ($event == 'diag') {
@@ -162,13 +171,13 @@ $LastChangedRevision: 2361 $
 		'dir_not_writable' =>
 		trim(
 			((!@is_writable($path_to_site.'/'.$img_dir))
-			?	str_replace('{dirtype}', gTxt('img_dir'), gTxt('dir_not_writable')).": {$path_to_site}/{$img_dir}\r\n"
+			?	str_replace('{dirtype}', gTxt('img_dir'), gTxt('dir_not_writable')).": {$path_to_site}/{$img_dir}".n
 			:	'').
 			((!@is_writable($file_base_path))
-			?	str_replace('{dirtype}', gTxt('file_base_path'), gTxt('dir_not_writable')).": {$file_base_path}\r\n"
+			?	str_replace('{dirtype}', gTxt('file_base_path'), gTxt('dir_not_writable')).": {$file_base_path}".n
 			:	'').
 			((!@is_writable($tempdir))
-			?	str_replace('{dirtype}', gTxt('tempdir'), gTxt('dir_not_writable')).": {$tempdir}\r\n"
+			?	str_replace('{dirtype}', gTxt('tempdir'), gTxt('dir_not_writable')).": {$tempdir}".n
 			:	'')),
 
 		'cleanurl_only_apache' =>
@@ -490,7 +499,7 @@ $LastChangedRevision: 2361 $
 				$table_msg[] = $table .cs. mysql_result($ctr,0,'Msg_Text');
 		}
 		if ($table_msg == array())
-			$table_msg = (count($table_names) < 18) ?  array('-') : array('OK');
+			$table_msg = (count($table_names) < 17) ?  array('-') : array('OK');
 		$out[] = count($table_names).' Tables'.cs. implode(', ',$table_msg).n;
 
 		$extns = get_loaded_extensions();
@@ -513,7 +522,7 @@ $LastChangedRevision: 2361 $
 			$rev = '';
 			$checksum = '';
 
-			if (is_callable('md5_file')) {
+			if (is_callable('md5_file') and is_readable(txpath . $f)) {
 				$checksum = md5_file(txpath . $f);
 			}
 
