@@ -13,8 +13,8 @@
 	"Mod File Upload" Copyright 2004 by Michael Manfre. All rights reserved.
 	Use of this mod denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_file.php $
-$LastChangedRevision: 2403 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_file.php $
+$LastChangedRevision: 2530 $
 
 */
 
@@ -192,7 +192,7 @@ $LastChangedRevision: 2403 $
 
 				$file_exists = file_exists(build_file_path($file_base_path, $filename));
 
-				$download_link = ($file_exists) ? '<li>'.make_download_link($id).'</li>' : '';
+				$download_link = ($file_exists) ? '<li>'.make_download_link($id, '', $filename).'</li>' : '';
 
 				$category = ($category) ? '<span title="'.htmlspecialchars(fetch_category_title($category, 'file')).'">'.$category.'</span>' : '';
 
@@ -300,6 +300,7 @@ $LastChangedRevision: 2403 $
 			if ($permissions=='') $permissions='-1';
 
 			$file_exists = file_exists(build_file_path($file_base_path,$filename));
+			$replace = ($file_exists) ? tr(td(file_upload_form(gTxt('replace_file'),'upload','file_replace',$id))) : '';
 
 			$existing_files = get_filenames();
 
@@ -309,7 +310,7 @@ $LastChangedRevision: 2403 $
 			$condition .= ($file_exists)?gTxt('file_status_ok'):gTxt('file_status_missing');
 			$condition .= '</span>';
 
-			$downloadlink = ($file_exists)?make_download_link($id, htmlspecialchars($filename)):htmlspecialchars($filename);
+			$downloadlink = ($file_exists)?make_download_link($id, htmlspecialchars($filename),$filename):htmlspecialchars($filename);
 			
 			$created =
 					n.graf(checkbox('publish_now', '1', $publish_now, '', 'publish_now').'<label for="publish_now">'.gTxt('set_to_now').'</label>').
@@ -374,6 +375,7 @@ $LastChangedRevision: 2403 $
 									hInput('category',$category).
 									hInput('perms',($permissions=='-1') ? '' : $permissions).
 									hInput('description',$description).
+									hInput('status',$status).
 
 									hInput('sort', $sort).
 									hInput('dir', $dir).
@@ -396,6 +398,7 @@ $LastChangedRevision: 2403 $
 				)
 			),
 			$form,
+			$replace,
 			endTable();
 		}
 	}
@@ -457,7 +460,7 @@ $LastChangedRevision: 2403 $
 
 		if ($file === false) {
 			// could not get uploaded file
-			file_list(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg(@$_FILES['file']['error']));
+			file_list(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg($_FILES['thefile']['error']));
 			return;
 		}
 
@@ -524,7 +527,7 @@ $LastChangedRevision: 2403 $
 
 		if ($file === false) {
 			// could not get uploaded file
-			file_list(gTxt('file_upload_failed') ." $name ".upload_get_errormsg($_FILES['file']['error']));
+			file_list(gTxt('file_upload_failed') ." $name ".upload_get_errormsg($_FILES['thefile']['error']));
 			return;
 		}
 
@@ -749,16 +752,10 @@ $LastChangedRevision: 2403 $
 
 // -------------------------------------------------------------
 
-	function make_download_link($id, $label = '')
+	function make_download_link($id, $label = '', $filename = '')
 	{
-		global $permlink_mode;
-
 		$label = ($label) ? $label : gTxt('download');
-
-		$url = ($permlink_mode == 'messy') ? 
-			hu.'index.php?s=file_download'.a.'id='.$id : 
-			hu.''.gTxt('file_download').'/'.$id;
-
+		$url = filedownloadurl($id, $filename);
 		return '<a href="'.$url.'">'.$label.'</a>';
 	}
 	
