@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement 
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_image.php $
-$LastChangedRevision: 2439 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_image.php $
+$LastChangedRevision: 2668 $
 
 */
 
@@ -18,7 +18,7 @@ $LastChangedRevision: 2439 $
 
 	global $extensions;
 	$extensions = array(0,'.gif','.jpg','.png','.swf',0,0,0,0,0,0,0,0,'.swf');
-	define("IMPATH",$path_to_site.'/'.$img_dir.'/');
+	define("IMPATH",$path_to_site.DS.$img_dir.DS);
 	include txpath.'/lib/class.thumb.php';
 
 	if ($event == 'image') {	
@@ -170,12 +170,26 @@ $LastChangedRevision: 2439 $
 
 				$name = empty($name) ? gTxt('unnamed') : htmlspecialchars($name);
 
-				$thumbnail = ($thumbnail) ?
-					'<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />' :
-					gTxt('no');
+				if ($thumbnail) {
+					if ($ext != '.swf') {
+						$thumbnail = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />';
+					} else {
+						$thumbnail = '';
+					}
+				} else {
+					$thumbnail = gTxt('no');
+				}
 
-				$tag_url = '?event=tag'.a.'tag_name=image'.a.'id='.$id.a.'ext='.$ext.
-					a.'w='.$w.a.'h='.$h.a.'alt='.urlencode($alt).a.'caption='.urlencode($caption);
+				if ($ext != '.swf') {
+					$tag_url = '?event=tag'.a.'tag_name=image'.a.'id='.$id.a.'ext='.$ext.a.'w='.$w.a.'h='.$h.a.'alt='.urlencode($alt).a.'caption='.urlencode($caption);
+					$tagbuilder = '<ul>'.
+							'<li><a target="_blank" href="'.$tag_url.a.'type=textile" onclick="popWin(this.href); return false;">Textile</a></li>'.
+							'<li><a target="_blank" href="'.$tag_url.a.'type=textpattern" onclick="popWin(this.href); return false;">Textpattern</a></li>'.
+							'<li><a target="_blank" href="'.$tag_url.a.'type=xhtml" onclick="popWin(this.href); return false;">XHTML</a></li>'.
+							'</ul>';
+				} else {
+					$tagbuilder = sp;
+				}
 
 				$category = ($category) ? '<span title="'.htmlspecialchars(fetch_category_title($category, 'image')).'">'.$category.'</span>' : '';
 
@@ -202,14 +216,7 @@ $LastChangedRevision: 2439 $
 						href($thumbnail, $edit_url)
 					, 80).
 
-					td(
-						'<ul>'.
-						'<li><a target="_blank" href="'.$tag_url.a.'type=textile" onclick="popWin(this.href); return false;">Textile</a></li>'.
-						'<li><a target="_blank" href="'.$tag_url.a.'type=textpattern" onclick="popWin(this.href); return false;">Textpattern</a></li>'.
-						'<li><a target="_blank" href="'.$tag_url.a.'type=xhtml" onclick="popWin(this.href); return false;">XHTML</a></li>'.
-						'</ul>'
-					, 85).
-
+					td($tagbuilder, 85).
 					td($category, 75).
 
 					td(
@@ -258,17 +265,27 @@ $LastChangedRevision: 2439 $
 		$categories = getTree("root", "image");
 		
 		$rs = safe_row("*", "txp_image", "id = $id");
-		
+
 		if ($rs) {
 			extract($rs);
+
+			if ($ext != '.swf') {
+				$img = '<img src="'.hu.$img_dir.'/'.$id.$ext.'" height="'.$h.'" width="'.$w.'" alt="" title="'.$id.$ext.' ('.$w.' &#215; '.$h.')" />';
+			} else {
+				$img = '';
+			}
+
+			if ($thumbnail and ($ext != '.swf')) {
+				$thumb = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />';
+			} else {
+				$thumb = '';
+			}
+
 			echo startTable('list'),
 			tr(
 				td(
-					'<img src="'.hu.$img_dir.
-						'/'.$id.$ext.'" height="'.$h.'" width="'.$w.'" alt="" '.
-						"title='$id$ext ($w &#215; $h)' />".
-						br.upload_form(gTxt('replace_image'),'replace_image_form',
-							'image_replace','image',$id,$file_max_upload_size, 'image-replace', '')
+					$img.br.
+					upload_form(gTxt('replace_image'), 'replace_image_form', 'image_replace', 'image', $id, $file_max_upload_size, 'image-replace', '')
 				)
 			),
 			tr(
@@ -278,7 +295,7 @@ $LastChangedRevision: 2439 $
 							($thumbnail)
 							? 	startTable('image-thumbnail').
 									tr(
-										td('<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />').
+										td($thumb).
 										td(dLink('image','thumbnail_delete','id',$id))
 									).
 								endTable().br
@@ -334,7 +351,7 @@ $LastChangedRevision: 2439 $
 
 		extract($txpcfg);
 
-		$meta = doSlash(gpsa(array('caption', 'alt', 'category')));
+		$meta = gpsa(array('caption', 'alt', 'category'));
 
 		$img_result = image_data($_FILES['thefile'], $meta);
 
@@ -438,34 +455,43 @@ $LastChangedRevision: 2439 $
 	}
 
 // -------------------------------------------------------------
-	function image_delete() 
-	{
+
+	function image_delete() {
 		global $txpcfg;
+
 		extract($txpcfg);
 
 		$id = assert_int(ps('id'));
-		
-		$rs = safe_row("*", "txp_image", "id = $id");
+
+		$rs = safe_row('*', 'txp_image', "id = $id");
+
 		if ($rs) {
 			extract($rs);
-			$rsd = safe_delete("txp_image","id = $id");
-			$ul = unlink(IMPATH.$id.$ext) or exit(image_list());
-			if(is_file(IMPATH.$id.'t'.$ext)){
+
+			$rsd = safe_delete('txp_image', "id = $id");
+
+			$ul = false;
+
+			if (is_file(IMPATH.$id.$ext)) {
+				$ul = unlink(IMPATH.$id.$ext);
+			}
+
+			if (is_file(IMPATH.$id.'t'.$ext)) {
 				$ult = unlink(IMPATH.$id.'t'.$ext);
 			}
 
-			if ($rsd && $ul)
-			{
-				$message = gTxt('image_deleted', array('{name}' => $name));
+			if ($rsd && $ul) {
 				update_lastmod();
 
-				image_list($message);
+				image_list(gTxt('image_deleted', array('{name}' => $name)));
+			} else {
+				image_list(gTxt('image_delete_failed', array('{name}' => $name)));
 			}
-		} else image_list();
+		} else {
+			image_list();
+		}
 	}
 
-
-	
 // -------------------------------------------------------------
 	function image_change_pageby()
 	{
@@ -627,7 +653,7 @@ $LastChangedRevision: 2439 $
 				$meta = array('category' => '', 'caption' => '', 'alt' => '');
 			}
 
-			extract($meta);
+			extract(doSlash($meta));
 
 			$q ="
 				name = '$name',
@@ -685,16 +711,22 @@ $LastChangedRevision: 2439 $
 					@chmod($newpath, 0644);
 
 					// GD is supported
-					if (check_gd($ext)) {
+					if (check_gd($ext))
+					{
 						// Auto-generate a thumbnail using the last settings
-						if (isset($prefs['thumb_w'], $prefs['thumb_h'], $prefs['thumb_crop'])) {
-							if (intval($prefs['thumb_w']) > 0 and intval($prefs['thumb_h']) > 0) {
+						if (isset($prefs['thumb_w'], $prefs['thumb_h'], $prefs['thumb_crop']))
+						{
+							$width  = intval($prefs['thumb_w']);
+							$height = intval($prefs['thumb_h']);
+
+							if ($width > 0 or $height > 0)
+							{
 								$t = new txp_thumb( $id );
 
 								$t->crop = ($prefs['thumb_crop'] == '1');
 								$t->hint = '0';
-								$t->width = intval($prefs['thumb_w']);
-								$t->height = intval($prefs['thumb_h']);
+								$t->width = $width;
+								$t->height = $height;
 
 								$t->write();
 							}
