@@ -10,8 +10,8 @@
 	Use of this software indicates acceptance of
 	the Textpattern license agreement 
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_log.php $
-$LastChangedRevision: 2439 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_log.php $
+$LastChangedRevision: 2796 $
 
 */
 	if (!defined('txpinterface'))
@@ -174,20 +174,17 @@ $LastChangedRevision: 2439 $
 
 				if ($log_refer)
 				{
-					$log_refer = htmlspecialchars('http://'.$log_refer);
+					$log_refer = 'http://'.$log_refer;
 
-					$log_refer = '<a href="'.$log_refer.'" target="_blank">'.soft_wrap($log_refer, 30).'</a>';
+					$log_refer = '<a href="'.htmlspecialchars($log_refer).'" target="_blank">'.htmlspecialchars(soft_wrap($log_refer, 30)).'</a>';
 				}
 
 				if ($log_page)
 				{
-					$log_page = htmlspecialchars($log_page);
-
-					$log_page = '<a href="'.$log_page.'" target="_blank">'.
-						soft_wrap(
-							preg_replace('/\/$/','', substr($log_page, 1))
-						, 30).
-						'</a>';
+					$log_anchor = preg_replace('/\/$/','',$log_page);
+					$log_anchor = soft_wrap(substr($log_anchor,1), 30);
+					
+					$log_page = '<a href="'.htmlspecialchars($log_page).'" target="_blank">'.htmlspecialchars($log_anchor).'</a>';
 
 					if ($log_method == 'POST')
 					{
@@ -207,7 +204,7 @@ $LastChangedRevision: 2439 $
 
 					td($log_page).
 					td($log_refer).
-					td($log_method, 60, 'log_detail').
+					td(htmlspecialchars($log_method), 60, 'log_detail').
 					td($log_status, 60, 'log_detail').
 
 					td(
