@@ -8,8 +8,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement 
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_page.php $
-$LastChangedRevision: 2099 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_page.php $
+$LastChangedRevision: 2717 $
 
 */
 	if (!defined('txpinterface')) die('txpinterface is undefined.');
@@ -159,16 +159,25 @@ $LastChangedRevision: 2099 $
 
 	function page_delete()
 	{
-		$name = doSlash(ps('name'));
+		$name  = ps('name');
+		$count = safe_count('txp_section', "page = '".doSlash($name)."'");
 
 		if ($name == 'default')
 		{
 			return page_edit();
 		}
 
-		safe_delete('txp_page', "name = '$name'");
+		if ($count)
+		{
+			$message = gTxt('page_used_by_section', array('{name}' => $name, '{count}' => $count));		
+		}
 
-		$message = gTxt('page_deleted', array('{name}' => $name));
+		else
+		{
+			safe_delete('txp_page', "name = '".doSlash($name)."'");
+
+			$message = gTxt('page_deleted', array('{name}' => $name));
+		}
 
 		page_edit($message);
 	}
@@ -182,6 +191,7 @@ $LastChangedRevision: 2099 $
 		if ($copy)
 		{
 			$newname = doSlash(trim(preg_replace('/[<>&"\']/', '', gps('newname'))));
+
 			if ($newname and safe_field('name', 'txp_page', "name = '$newname'"))
 			{
 				$message = gTxt('page_already_exists', array('{name}' => $newname));
