@@ -7,27 +7,27 @@
 	www.textpattern.com
 	All rights reserved
 
-	Use of this software indicates acceptance of the Textpattern license agreement 
+	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_plugin.php $
-$LastChangedRevision: 1917 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_plugin.php $
+$LastChangedRevision: 2774 $
 
 */
 
 	if (!defined('txpinterface')) die('txpinterface is undefined.');
 
 	if ($event == 'plugin') {
-		require_privs('plugin');		
+		require_privs('plugin');
 
 		if(!$step or !in_array($step, array('plugin_delete','plugin_edit','plugin_help','plugin_list','plugin_install','plugin_save','plugin_verify','switch_status'))){
 			plugin_list();
 		} else $step();
 	}
-	
+
 // -------------------------------------------------------------
 
 	function plugin_list($message = '')
-	{	
+	{
 		pagetop(gTxt('edit_plugins'), $message);
 
 		echo n.n.startTable('list').
@@ -37,7 +37,8 @@ $LastChangedRevision: 1917 $
 				,' colspan="8" style="height: 30px; border: none;"')
 			);
 
-		$rs = safe_rows_start('*, md5(code) as md5', 'txp_plugin', "1 order by name");
+		$rs = safe_rows_start('name, status, author, author_uri, version, description, code_md5, length(help) as help, md5(code) as md5',
+			'txp_plugin', '1 order by name');
 
 		if ($rs and numRows($rs) > 0)
 		{
@@ -95,7 +96,7 @@ $LastChangedRevision: 1917 $
 
 		echo endTable();
 	}
-	
+
 // -------------------------------------------------------------
 
 	function switch_status()
@@ -119,22 +120,22 @@ $LastChangedRevision: 1917 $
 		echo plugin_edit_form($name);
   }
 
-  
+
 // -------------------------------------------------------------
-	function plugin_help() 
+	function plugin_help()
 	{
 		$name = gps('name');
 		pagetop(gTxt('plugin_help'));
 		$help = ($name) ? safe_field('help','txp_plugin',"name = '".doSlash($name)."'") : '';
-		echo 
+		echo
 		startTable('edit')
 		.	tr(tda($help,' width="600"'))
 		.	endTable();
-		
+
 	}
 
 // -------------------------------------------------------------
-	function plugin_edit_form($name='') 
+	function plugin_edit_form($name='')
 	{
 		$sub = fInput('submit','',gTxt('save'),'publish');
 		$code = ($name) ? fetch('code','txp_plugin','name',$name) : '';
@@ -143,7 +144,7 @@ $LastChangedRevision: 1917 $
 		:	'';
 		$textarea = '<textarea id="plugin-code" class="code" name="code" rows="28" cols="90">'.htmlspecialchars($thing).'</textarea>';
 
-		return 
+		return
 		form(startTable('edit')
 		.	tr(td($textarea))
 		.	tr(td($sub))
@@ -151,7 +152,7 @@ $LastChangedRevision: 1917 $
 		.	endTable().sInput('plugin_save').eInput('plugin').hInput('name',$name));
 	}
 
-// -------------------------------------------------------------  
+// -------------------------------------------------------------
 
 	function plugin_save()
 	{
@@ -188,13 +189,13 @@ $LastChangedRevision: 1917 $
 	}
 
 // -------------------------------------------------------------
-	function plugin_verify() 
-	{	
+	function plugin_verify()
+	{
 
 		if (ps('txt_plugin')) {
 			$plugin = join("\n", file($_FILES['theplugin']['tmp_name']));
 		} else {
-			$plugin = ps('plugin');	
+			$plugin = ps('plugin');
 		}
 
 		$plugin = preg_replace('@.*\$plugin=\'([\w=+/]+)\'.*@s', '$1', $plugin);
@@ -203,11 +204,23 @@ $LastChangedRevision: 1917 $
 		if(isset($plugin)) {
 			$plugin_encoded = $plugin;
 			$plugin = base64_decode($plugin);
-			if (strncmp($plugin,"\x1F\x8B",2)===0)
-				$plugin = gzinflate(substr($plugin, 10));
+
+			if (strncmp($plugin, "\x1F\x8B", 2) === 0)
+			{
+				if (function_exists('gzinflate'))
+				{
+					$plugin = gzinflate(substr($plugin, 10));
+				}
+
+				else
+				{
+					plugin_list(gTxt('plugin_compression_unsupported'));
+					return;
+				}
+			}
 
 			if ($plugin = @unserialize($plugin))
-			{ 
+			{
 				if(is_array($plugin)){
 					extract($plugin);
 					$source = '';
@@ -220,9 +233,9 @@ $LastChangedRevision: 1917 $
 					}
 					$source.= highlight_string('<?php'.$plugin['code'].'?>', true);
 					$sub = fInput('submit','',gTxt('install'),'publish');
-		
+
 					pagetop(gTxt('edit_plugins'));
-					echo 
+					echo
 					form(
 						hed(gTxt('previewing_plugin'), 3).
 						tag($source, 'div', ' id="preview-plugin" class="code"').
@@ -240,12 +253,12 @@ $LastChangedRevision: 1917 $
 		plugin_list(gTxt('bad_plugin_code'));
 
 	}
-	
-// -------------------------------------------------------------
-	function plugin_install() 
-	{	
 
-		$plugin = ps('plugin64');	
+// -------------------------------------------------------------
+	function plugin_install()
+	{
+
+		$plugin = ps('plugin64');
 
 		$plugin = preg_replace('@.*\$plugin=\'([\w=+/]+)\'.*@s', '$1', $plugin);
 		$plugin = preg_replace('/^#.*$/m', '', $plugin);
@@ -309,14 +322,14 @@ $LastChangedRevision: 1917 $
 
 					if ($rs and $code)
 					{
-						$message = gTxt('plugin_installed', array('{name}' => escape_output($name)));
+						$message = gTxt('plugin_installed', array('{name}' => htmlspecialchars($name)));
 
 						plugin_list($message);
 					}
 
 					else
 					{
-						$message = gTxt('plugin_install_failed', array('{name}' => escape_output($name)));
+						$message = gTxt('plugin_install_failed', array('{name}' => htmlspecialchars($name)));
 
 						plugin_list($message);
 					}
@@ -332,7 +345,7 @@ $LastChangedRevision: 1917 $
 
 // -------------------------------------------------------------
 
-	function plugin_form() 
+	function plugin_form()
 	{
 		return n.n.form(
 			graf(
