@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/include/txp_tag.php $
-$LastChangedRevision: 2260 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_tag.php $
+$LastChangedRevision: 2774 $
 
 */
 
@@ -364,6 +364,21 @@ begin generic functions
 		return ' '.selectInput('sort', $vals, $val, true);
 	}
 
+	function list_sort_pop($val)
+	{
+		$asc = ' ('.gTxt('ascending').')';
+		$desc = ' ('.gTxt('descending').')';
+
+		$vals = array(
+			'title asc'		=> gTxt('tag_title').$asc,
+			'title desc'	=> gTxt('tag_title').$desc,
+			'name asc'		=> gTxt('name').$asc,
+			'name desc'		=> gTxt('name').$desc,
+		);
+
+		return ' '.selectInput('sort', $vals, $val, true);
+	}
+
 //--------------------------------------------------------------
 
 	function pgonly_pop($val)
@@ -793,6 +808,7 @@ begin tag builder functions
 			'label',
 			'labeltag',
 			'sections',
+			'sort',
 			'wraptag'
 		));
 
@@ -810,6 +826,9 @@ begin tag builder functions
 			tagRow('include_default',
 				yesno_pop('include_default', $include_default)).
 
+			tagRow('sort',
+				list_sort_pop($sort)).
+
 			tagRow('default_title',
 				fInput('text', 'default_title', $default_title, 'edit', '', '', 20)).
 
@@ -865,6 +884,7 @@ begin tag builder functions
 			'labeltag',
 			'parent',
 			'section',
+			'sort',
 			'this_section',
 			'type',
 			'wraptag',
@@ -899,6 +919,9 @@ begin tag builder functions
 			tagRow('category_list_section',
 				section_pop('section', $section)).
 
+			tagRow('sort',
+				list_sort_pop($sort)).
+
 			tagRow('label',
 				fInput('text', 'label', ($label ? $label : gTxt('categories')), 'edit', '', '', 20)).
 
@@ -1887,7 +1910,7 @@ begin tag builder functions
 
 // -------------------------------------------------------------
 
-	function tag_sitename()
+	function tag_site_name()
 	{
 		global $step, $endform, $tag_name;
 
@@ -2782,6 +2805,7 @@ begin tag builder functions
 			'class',
 			'id',
 			'form',
+			'sort',
 			'wraptag'
 		));
 
@@ -2802,6 +2826,9 @@ begin tag builder functions
 			tagRow('form',
 				form_pop('form', 'comment', $form)).
 
+			tagRow('sort',
+				discuss_sort_pop($sort)).
+
 			tagRow('wraptag',
 				input_tag('wraptag', $wraptag)).
 
@@ -3207,8 +3234,8 @@ begin tag builder functions
 		{
 			if ($escape == 'html')
 			{
-				$alt = str_replace('&', '&#38;', escape_output($alt));
-				$caption = str_replace('&', '&#38;', escape_output($caption));
+				$alt = str_replace('&', '&#38;', htmlspecialchars($alt));
+				$caption = str_replace('&', '&#38;', htmlspecialchars($caption));
 			}
 
 			$url = hu.$img_dir.'/'.$id.$ext;
@@ -3562,7 +3589,7 @@ begin tag builder functions
 
 		if ($step == 'build')
 		{
-			$description = str_replace('&', '&#38;', escape_output($description));
+			$description = str_replace('&', '&#38;', htmlspecialchars($description));
 
 			$url = ($permlink_mode == 'messy') ?
 				hu.'index.php?s=file_download'.a.'id='.$id:
