@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement 
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/index.php $
-$LastChangedRevision: 2466 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/index.php $
+$LastChangedRevision: 2805 $
 
 */
 	if (@ini_get('register_globals'))
@@ -20,7 +20,7 @@ $LastChangedRevision: 2466 $
 	define("txpath", dirname(__FILE__));
 	define("txpinterface", "admin");
 
-	$thisversion = '4.0.5';
+	$thisversion = '4.0.6';
 	$txp_using_svn = false; // set false for releases
 
 	ob_start(NULL, 2048);
@@ -41,10 +41,10 @@ $LastChangedRevision: 2466 $
 	@ini_set("display_errors","1");
 
 	include_once txpath.'/lib/constants.php';
+	include txpath.'/lib/txplib_misc.php';
 	include txpath.'/lib/txplib_db.php';
 	include txpath.'/lib/txplib_forms.php';
 	include txpath.'/lib/txplib_html.php';
-	include txpath.'/lib/txplib_misc.php';
 	include txpath.'/lib/admin_config.php';
 
 	$microstart = getmicrotime();
@@ -64,8 +64,20 @@ $LastChangedRevision: 2466 $
 		define("LANG",$language);
 		//i18n: define("LANG","en-gb");
 		define('txp_version', $thisversion);
-		if ( !defined(  'PROTOCOL'))
-			define(  'PROTOCOL', (  (  serverSet( 'HTTPS') != '' ) ? 'https://' : 'http://') );
+
+		if (!defined('PROTOCOL')) {
+			switch (serverSet('HTTPS')) {
+				case '':
+				case 'off': // ISAPI with IIS
+					define('PROTOCOL', 'http://');
+				break;
+
+				default:
+					define('PROTOCOL', 'https://');
+				break;
+			}
+		}
+
 		define("hu",PROTOCOL.$siteurl.'/');
 		// v1.0 experimental relative url global
 		define("rhu",preg_replace("/https?:\/\/.+(\/.*)\/?$/U","$1",hu));
