@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/lib/taglib.php $
-$LastChangedRevision: 1535 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/taglib.php $
+$LastChangedRevision: 2612 $
 */
 
 $article_tags = array(
@@ -104,7 +104,7 @@ $page_xml_tags = array(
 $page_misc_tags = array(
 	'page_title',
 	'css',
-	'sitename',
+	'site_name',
 	'site_slogan',
 	'breadcrumb',
 	'search_input',
@@ -121,4 +121,4 @@ $page_file_tags = array(
 	'file_download_link',
 );
 
-?>
\ No newline at end of file
+?>
