@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/lib/txplib_db.php $
-$LastChangedRevision: 2406 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/txplib_db.php $
+$LastChangedRevision: 2748 $
 */
 
 if (!defined('PFX')) {
@@ -69,11 +69,8 @@ $DB = new DB;
 		global $DB,$txpcfg, $qcount, $qtime, $production_status;
 		$method = (!$unbuf) ? 'mysql_query' : 'mysql_unbuffered_query';
 		if (!$q) return false;
-		if ($debug or TXP_DEBUG === 1) { 
-			dmp($q);
-			dmp(mysql_error());
-//			dmp(debug_backtrace());
-		}
+		if ($debug or TXP_DEBUG === 1) dmp($q);
+
 		$start = getmicrotime();
 		$result = $method($q,$DB->link);
 		$time = sprintf('%02.6f', getmicrotime() - $start);
@@ -458,14 +455,14 @@ $DB = new DB;
 			}
 			return $out;
 		}
-		return false;
+		return array();
 	}
 
 // -------------------------------------------------------------
 	function db_down()
 	{
 		// 503 status might discourage search engines from indexing or caching the error message
-		header('Status: 503 Service Unavailable');
+		txp_status_header('503 Service Unavailable');
 		$error = mysql_error();
 		return <<<eod
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
