@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/lib/txplib_head.php $
-$LastChangedRevision: 2404 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/txplib_head.php $
+$LastChangedRevision: 2783 $
 */
 
 // -------------------------------------------------------------
@@ -14,18 +14,38 @@ $LastChangedRevision: 2404 $
 		$bm = gps('bm');
 
 		$privs = safe_field("privs", "txp_users", "name = '".doSlash($txp_user)."'");
-		
+
 		$GLOBALS['privs'] = $privs;
 
 		$areas = areas();
-		foreach ($areas as $k=>$v) {
+		$area = false;
+
+		foreach ($areas as $k => $v)
+		{
 			if (in_array($event, $v))
+			{
 				$area = $k;
+				break;
+			}
 		}
-		
-	?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-			"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-	<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
+
+		if (gps('logout'))
+		{
+			$body_id = 'page-logout';
+		}
+
+		elseif (!$txp_user)
+		{
+			$body_id = 'page-login';
+		}
+
+		else
+		{
+			$body_id = 'page-'.$event;
+		}
+
+	?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+	<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo LANG; ?>" lang="<?php echo LANG; ?>" dir="<?php echo gTxt('lang_dir'); ?>">
 	<head>
 	<meta http-equiv="content-type" content="text/html; charset=utf-8" />
 	<meta name="robots" content="noindex, nofollow" />
@@ -40,14 +60,14 @@ $LastChangedRevision: 2404 $
 		if (!cookieEnabled)
 		{
 			confirm('<?php echo trim(gTxt('cookies_must_be_enabled')); ?>');
-		}	
-	
+		}
+
 <?php
 
 	if ($event == 'list')
 	{
 		$sarr = array("\n", '-');
-		$rarr = array('', '&#45;'); 
+		$rarr = array('', '&#45;');
 
 		$sections = '';
 
@@ -163,7 +183,7 @@ $LastChangedRevision: 2404 $
 	</script>
 	<script type="text/javascript" src="jquery.js"></script>
 	</head>
-	<body>
+	<body id="<?php echo $body_id; ?>">
   <table id="pagetop" cellpadding="0" cellspacing="0">
   <tr id="branding"><td><img src="txp_img/textpattern.gif" alt="textpattern" /></td><td id="navpop"><?php echo navPop(1); ?></td></tr>
   <tr id="nav-primary"><td align="center" class="tabs" colspan="2">
@@ -171,7 +191,7 @@ $LastChangedRevision: 2404 $
  		if (!$bm) {
 			echo '<table cellpadding="0" cellspacing="0" align="center"><tr>
   <td valign="middle" style="width:368px">&nbsp;'.$message.'</td>',
-  			
+
 			has_privs('tab.content')
 			? areatab(gTxt('tab_content'), 'content', 'article', $area)
 			: '',
@@ -185,9 +205,9 @@ $LastChangedRevision: 2404 $
 			?	areatab(gTxt('tab_extensions'), 'extensions', array_shift($areas['extensions']), $area)
 			:	'',
 
-			'<td class="tabdown"><a href="'.hu.'" class="plain" target="blank">'.gTxt('tab_view_site').'</a></td>',
+			'<td class="tabdown"><a href="'.hu.'" class="plain" target="_blank">'.gTxt('tab_view_site').'</a></td>',
 		 '</tr></table>',
-		
+
 		'</td></tr><tr id="nav-secondary"><td align="center" class="tabs" colspan="2">
 			<table cellpadding="0" cellspacing="0" align="center"><tr>',
 				tabsort($area,$event),
@@ -197,49 +217,61 @@ $LastChangedRevision: 2404 $
 	}
 
 // -------------------------------------------------------------
-	function areatab($label,$event,$tarea,$area) 
+	function areatab($label,$event,$tarea,$area)
 	{
 		$tc = ($area == $event) ? 'tabup' : 'tabdown';
-		$atts=' class="'.$tc.'" onclick="window.location.href=\'?event='.$tarea.'\'"';
+		$atts=' class="'.$tc.'"';
 		$hatts=' href="?event='.$tarea.'" class="plain"';
       	return tda(tag($label,'a',$hatts),$atts);
 	}
 
 // -------------------------------------------------------------
-	function tabber($label,$tabevent,$event) 
-	{		
-		$tc = ($event==$tabevent) ? 'tabup' : 'tabdown2';
-		$out = '<td class="'.$tc.'" onclick="window.location.href=\'?event='.$tabevent.'\'" ><a href="?event='.$tabevent.'" class="plain">'.$label.'</a></td>';
-      	return $out;
-	}
-
-// -------------------------------------------------------------
-	function tabsort($area,$event) 
+	function tabber($label,$tabevent,$event)
 	{
-		$areas = areas();
-		foreach($areas[$area] as $a=>$b) {
-			if (has_privs($b)) {
-				$out[] = tabber($a,$b,$event,2);
-			}
-		}
-		return (empty($out) ? '' : join('',$out));
+		$tc = ($event==$tabevent) ? 'tabup' : 'tabdown2';
+		$out = '<td class="'.$tc.'"><a href="?event='.$tabevent.'" class="plain">'.$label.'</a></td>';
+		return $out;
 	}
 
 // -------------------------------------------------------------
-	function areas() 
+
+	function tabsort($area, $event)
+	{
+		if ($area)
+		{
+			$areas = areas();
+
+			$out = array();
+
+			foreach ($areas[$area] as $a => $b)
+			{
+				if (has_privs($b))
+				{
+					$out[] = tabber($a, $b, $event, 2);
+				}
+			}
+
+			return ($out) ? join('', $out) : '';
+		}
+
+		return '';
+	}
+
+// -------------------------------------------------------------
+	function areas()
 	{
 		global $privs, $plugin_areas;
-		
+
 		$areas['content'] = array(
 			gTxt('tab_organise') => 'category',
 			gTxt('tab_write')    => 'article',
 			gTxt('tab_list')    =>  'list',
 			gTxt('tab_image')    => 'image',
-			gTxt('tab_file')	 => 'file',			
+			gTxt('tab_file')	 => 'file',
 			gTxt('tab_link')     => 'link',
 			gTxt('tab_comments') => 'discuss'
 		);
-		
+
 		$areas['presentation'] = array(
 			gTxt('tab_sections') => 'section',
 			gTxt('tab_pages')    => 'page',
@@ -254,7 +286,7 @@ $LastChangedRevision: 2404 $
 			gTxt('tab_logs')        => 'log',
 			gTxt('tab_plugins')     => 'plugin',
 			gTxt('tab_import')      => 'import'
-		);	
+		);
 
 		$areas['extensions'] = array(
 		);
@@ -262,7 +294,7 @@ $LastChangedRevision: 2404 $
 		if (is_array($plugin_areas))
 			$areas = array_merge_recursive($areas, $plugin_areas);
 
-		return $areas;	
+		return $areas;
 	}
 
 // -------------------------------------------------------------
@@ -300,7 +332,7 @@ $LastChangedRevision: 2404 $
 		{
 			$style = ($inline) ? ' style="display: inline;"': '';
 
-			return '<form method="get" action="index.php"'.$style.'>'.
+			return '<form method="get" action="index.php" class="navpop"'.$style.'>'.
 				n.'<select name="event" onchange="submit(this.form);">'.
 				n.t.'<option>'.gTxt('go').'&#8230;</option>'.
 				join('', $out).
@@ -310,7 +342,7 @@ $LastChangedRevision: 2404 $
 	}
 
 // -------------------------------------------------------------
-	function button($label,$link) 
+	function button($label,$link)
 	{
 		return '<span style="margin-right:2em"><a href="?event='.$link.'" class="plain">'.$label.'</a></span>';
 	}
