@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/lib/txplib_misc.php $
-$LastChangedRevision: 2464 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/txplib_misc.php $
+$LastChangedRevision: 2788 $
 */
 
 // -------------------------------------------------------------
@@ -30,7 +30,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function deEntBrackets($in) 
+	function deEntBrackets($in)
 	{
 		$array = array(
 			'&#60;'  => '<',
@@ -40,7 +40,7 @@ $LastChangedRevision: 2464 $
 			'&gt;'   => '>',
 			'&#x3E;' => '>'
 		);
-		
+
 		foreach($array as $k=>$v){
 			$in = preg_replace("/".preg_quote($k)."/i",$v, $in);
 		}
@@ -88,18 +88,10 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
+// deprecated, use htmlspecialchars instead. Remove in crockery
 	function escape_output($str)
 	{
-		# should be safe for xhtml and xml
-		return strtr($str,
-			array(
-				'&' => '&#38;',
-				'<' => '&#60;',
-				'>' => '&#62;',
-				"'" => '&#39;',
-				'"' => '&#34;',
-			)
-		);
+		return htmlspecialchars($str);
 	}
 
 // -------------------------------------------------------------
@@ -140,28 +132,54 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-    function dmp() 
-    {
+	function dmp()
+	{
+		static $f = FALSE;
+
+		if(defined('txpdmpfile'))
+		{
+			global $prefs;
+
+			if(!$f) $f = fopen($prefs['tempdir'].'/'.txpdmpfile, 'a');
+
+			fwrite($f, "\n[".safe_strftime('iso8601')."]\n");
+		}
+
 		$a = func_get_args();
-		echo "<pre>".n;
+
+		if(!$f) echo "<pre>".n;
+
 		foreach ($a as $thing)
-			echo htmlspecialchars(is_scalar($thing) ? strval($thing) : var_export($thing, true)), n;
-		echo "</pre>".n;
-    }
+		{
+			$out = is_scalar($thing) ? strval($thing) : var_export($thing, true);
+
+			if ($f)
+			{
+				fwrite($f, $out."\n");
+			}
+			else
+			{
+				echo htmlspecialchars($out), n;
+			}
+		}
+
+		if(!$f) echo "</pre>".n;
+	}
 
 // -------------------------------------------------------------
 	function load_lang($lang)
 	{
 		global $txpcfg;
 
-		$installed = safe_field('name', 'txp_lang',"lang='".doSlash($lang)."' limit 1");
-
-		$lang_code = ($installed)? $lang : 'en-gb';
-
-		$rs = (txpinterface == 'admin')
+		foreach(array($lang, 'en-gb') as $lang_code)
+		{
+			$rs = (txpinterface == 'admin')
 				? safe_rows_start('name, data','txp_lang',"lang='".doSlash($lang_code)."'")
 				: safe_rows_start('name, data','txp_lang',"lang='".doSlash($lang_code)."' AND ( event='public' OR event='common')");
 
+			if (mysql_num_rows($rs)) break;
+		}
+
 		$out = array();
 
 		if ($rs && mysql_num_rows($rs) > 0)
@@ -187,7 +205,7 @@ $LastChangedRevision: 2464 $
 				@fclose($filename);
 			}
 		}
-		
+
 		return $out;
 	}
 
@@ -206,31 +224,31 @@ $LastChangedRevision: 2464 $
 				$out[trim($name)] = trim($val);
 			}
 			return $out;
-		} 
+		}
 		return false;
 	}
 // -------------------------------------------------------------
 
 	function load_lang_event($event)
-	{		
+	{
 		global $txpcfg;
 		$lang = LANG;
-				
+
 		$installed = safe_field('name', 'txp_lang',"lang='".doSlash($lang)."' limit 1");
-		
+
 		$lang_code = ($installed)? $lang : 'en-gb';
-				
-		$rs = safe_rows_start('name, data','txp_lang',"lang='".doSlash($lang_code)."' AND event='".doSlash($event)."'");		
-		
+
+		$rs = safe_rows_start('name, data','txp_lang',"lang='".doSlash($lang_code)."' AND event='".doSlash($event)."'");
+
 		$out = array();
 
 		if ($rs && !empty($rs))
 		{
 			while ($a = nextRow($rs))
 			{
-				$out[$a['name']] = $a['data']; 
+				$out[$a['name']] = $a['data'];
 			}
-		}		
+		}
 		return ($out) ? $out : '';
 	}
 
@@ -270,11 +288,15 @@ $LastChangedRevision: 2464 $
 			$privs[$user] = safe_field("privs", "txp_users", "name='".doSlash($user)."'");
 		}
 
-		if (@$txp_permissions[$res])
-			$req = explode(',', $txp_permissions[$res]);
+		if (isset($txp_permissions[$res]))
+		{
+			return in_array($privs[$user], explode(',', $txp_permissions[$res]));
+		}
+
 		else
-			$req = array('1'); // The Publisher gets prived for anything
-		return in_array($privs[$user], $req);
+		{
+			return false;
+		}
 	}
 
 // -------------------------------------------------------------
@@ -286,7 +308,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function sizeImage($name) 
+	function sizeImage($name)
 	{
 		$size = @getimagesize($name);
 		return(is_array($size)) ? $size[3] : false;
@@ -353,9 +375,9 @@ $LastChangedRevision: 2464 $
 		}
 		return $out;
 	}
-	
+
 // -------------------------------------------------------------
-	function stripPost() 
+	function stripPost()
 	{
 		if (isset($_POST)) {
 			if (MAGIC_QUOTES_GPC) {
@@ -368,13 +390,13 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function serverSet($thing) // Get a var from $_SERVER global array, or create it 
+	function serverSet($thing) // Get a var from $_SERVER global array, or create it
 	{
 		return (isset($_SERVER[$thing])) ? $_SERVER[$thing] : '';
 	}
 
 // -------------------------------------------------------------
- 	function pcs($thing) //	Get a var from POST or COOKIE; if not, create it 
+ 	function pcs($thing) //	Get a var from POST or COOKIE; if not, create it
 	{
 		if (isset($_COOKIE["txp_".$thing])) {
 			if (MAGIC_QUOTES_GPC) {
@@ -384,12 +406,12 @@ $LastChangedRevision: 2464 $
 			if (MAGIC_QUOTES_GPC) {
 				return doStrip($_POST[$thing]);
 			} else return $_POST[$thing];
-		} 
+		}
 		return '';
 	}
 
 // -------------------------------------------------------------
- 	function cs($thing) //	Get a var from COOKIE; if not, create it 
+ 	function cs($thing) //	Get a var from COOKIE; if not, create it
 	{
 		if (isset($_COOKIE[$thing])) {
 			if (MAGIC_QUOTES_GPC) {
@@ -400,16 +422,17 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function yes_no($status) 
+	function yes_no($status)
 	{
 		return ($status==0) ? (gTxt('no')) : (gTxt('yes'));
 	}
-	
+
 // -------------------------------------------------------------
-	function getmicrotime() { 
-    	list($usec, $sec) = explode(" ",microtime()); 
-    	return ((float)$usec + (float)$sec); 
-    }
+	function getmicrotime()
+	{
+		list($usec, $sec) = explode(" ",microtime());
+		return ((float)$usec + (float)$sec);
+	}
 
 // -------------------------------------------------------------
 	function load_plugin($name)
@@ -419,7 +442,7 @@ $LastChangedRevision: 2464 $
 		if (is_array($plugins) and in_array($name,$plugins)) {
 			return true;
 		}
-		
+
 		if (!empty($prefs['plugin_cache_dir'])) {
 			$dir = rtrim($prefs['plugin_cache_dir'], '/') . '/';
 			# in case it's a relative path
@@ -435,20 +458,20 @@ $LastChangedRevision: 2464 $
 				return true;
 			}
 		}
-							
+
 		$rs = safe_row("name,code,version","txp_plugin","status = 1 AND name='".doSlash($name)."'");
 		if ($rs) {
 			$plugins[] = $rs['name'];
 			$plugins_ver[$rs['name']] = $rs['version'];
-			
+
 			set_error_handler("pluginErrorHandler");
 			$txp_current_plugin = $rs['name'];
 			eval($rs['code']);
 			restore_error_handler();
-			
-			return true;	
+
+			return true;
 		}
-		
+
 		return false;
 	}
 
@@ -458,7 +481,7 @@ $LastChangedRevision: 2464 $
 		if (!load_plugin($name))
 			trigger_error("Unable to include required plugin \"{$name}\"",E_USER_ERROR);
 	}
-	
+
 // -------------------------------------------------------------
 	function include_plugin($name)
 	{
@@ -469,7 +492,7 @@ $LastChangedRevision: 2464 $
 // -------------------------------------------------------------
 	function pluginErrorHandler($errno, $errstr, $errfile, $errline)
 	{
-		$error = array( E_WARNING => "Warning", E_NOTICE => "Notice", E_USER_ERROR => "User_Error", 
+		$error = array( E_WARNING => "Warning", E_NOTICE => "Notice", E_USER_ERROR => "User_Error",
 						E_USER_WARNING => "User_Warning", E_USER_NOTICE => "User_Notice");
 
 		if (!($errno & error_reporting())) return;
@@ -478,7 +501,7 @@ $LastChangedRevision: 2464 $
 		printf ("<pre>".gTxt('plugin_load_error').' <b>%s</b> -> <b>%s: %s on line %s</b></pre>',
 				$txp_current_plugin, $error[$errno], $errstr, $errline);
 		if ($production_status == 'debug')
-			print "\n<pre style=\"padding-left: 2em;\" class=\"backtrace\"><code>".escape_output(join("\n", get_caller(10)))."</code></pre>";
+			print "\n<pre style=\"padding-left: 2em;\" class=\"backtrace\"><code>".htmlspecialchars(join("\n", get_caller(10)))."</code></pre>";
 	}
 
 // -------------------------------------------------------------
@@ -486,7 +509,7 @@ $LastChangedRevision: 2464 $
 	{
 		global $production_status;
 
-		$error = array( E_WARNING => "Warning", E_NOTICE => "Notice", E_USER_ERROR => "Textpattern Error", 
+		$error = array( E_WARNING => "Warning", E_NOTICE => "Notice", E_USER_ERROR => "Textpattern Error",
 						E_USER_WARNING => "Textpattern Warning", E_USER_NOTICE => "Textpattern Notice");
 
 		if (!($errno & error_reporting())) return;
@@ -497,21 +520,38 @@ $LastChangedRevision: 2464 $
 		printf ("<pre>".gTxt('tag_error').' <b>%s</b> -> <b> %s: %s %s</b></pre>',
 				htmlspecialchars($txp_current_tag), $error[$errno], $errstr, $errline );
 		if ($production_status == 'debug')
-			print "\n<pre style=\"padding-left: 2em;\" class=\"backtrace\"><code>".escape_output(join("\n", get_caller(10)))."</code></pre>";
+			{
+			print "\n<pre style=\"padding-left: 2em;\" class=\"backtrace\"><code>".htmlspecialchars(join("\n", get_caller(10)))."</code></pre>";
+
+			$trace_msg = gTxt('tag_error').' '.$txp_current_tag.' -> '.$error[$errno].': '.$errstr.' '.$errline;
+			trace_add( $trace_msg );
+			}
 	}
 
 // -------------------------------------------------------------
-   function load_plugins($type=NULL)
-   {
+	function feedErrorHandler($errno, $errstr, $errfile, $errline)
+	{
+		global $production_status;
+
+		if ($production_status != 'debug') return;
+
+		return tagErrorHandler($errno, $errstr, $errfile, $errline);
+	}
+
+// -------------------------------------------------------------
+	function load_plugins($type=NULL)
+	{
 		global $prefs,$plugins, $plugins_ver;
-		
+
 		if (!is_array($plugins)) $plugins = array();
-		
+
 		if (!empty($prefs['plugin_cache_dir'])) {
-			$dir = rtrim($prefs['plugin_cache_dir'], '/') . '/';
+			$dir = rtrim($prefs['plugin_cache_dir'], DS) . DS;
 			# allow a relative path
-			if (!is_dir($dir))
-				$dir = rtrim(realpath(txpath.'/'.$dir), '/') . '/';
+			if (!is_dir($dir)) {
+				$dir = realpath(txpath.DS.$dir);
+				if($dir) $dir = rtrim($dir, DS) . DS;
+			}
 			$dh = @opendir($dir);
 			while ($dh and false !== ($f = @readdir($dh))) {
 				if ($f{0} != '.')
@@ -532,17 +572,17 @@ $LastChangedRevision: 2464 $
 					$plugins_ver[$a['name']] = $a['version'];
 					$GLOBALS['txp_current_plugin'] = $a['name'];
 					$eval_ok = eval($a['code']);
-					if ($eval_ok === FALSE) 
+					if ($eval_ok === FALSE)
 						echo gTxt('plugin_load_error_above').strong($a['name']).n.br;
 					unset($GLOBALS['txp_current_plugin']);
 				}
 			}
 			restore_error_handler();
 		}
-   }
+	}
 
 // -------------------------------------------------------------
-   function register_callback($func, $event, $step='', $pre=0)
+	function register_callback($func, $event, $step='', $pre=0)
 	{
 		global $plugin_callback;
 
@@ -550,14 +590,14 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-   function register_page_extension($func, $event, $step='', $top=0)
+	function register_page_extension($func, $event, $step='', $top=0)
 	{
 		# For now this just does the same as register_callback
 		register_callback($func, $event, $step, $top);
 	}
 
 // -------------------------------------------------------------
-   function callback_event($event, $step='', $pre=0)
+	function callback_event($event, $step='', $pre=0)
 	{
 		global $plugin_callback;
 
@@ -575,40 +615,50 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function register_tab($area, $event, $title) 
+	function register_tab($area, $event, $title)
 	{
 		global $plugin_areas;
-		
+
 		$plugin_areas[$area][$title] = $event;
 	}
 
 // -------------------------------------------------------------
-	// deprecated, use lAtts instead
-	function getAtt($name, $default=NULL) { // thanks zem!
+	// deprecated, use lAtts instead. Remove in crockery
+	function getAtt($name, $default=NULL)
+	{
 		global $theseatts;
 		return isset($theseatts[$name]) ? $theseatts[$name] : $default;
 	}
-	
-// -------------------------------------------------------------
-		function gAtt(&$atts, $name, $default=NULL) {
-			return isset($atts[$name]) ? $atts[$name] : $default;
-		}
 
 // -------------------------------------------------------------
-		function lAtts($pairs, $atts, $warn=1) {
-			global $production_status;
-			foreach($pairs as $name => $default) {
-				$out[$name] = gAtt($atts,$name,$default);
-			}
-			if ($warn and ($production_status == 'debug' or $production_status == 'testing')) {
-				foreach (array_diff(array_keys($atts), array_keys($pairs)) as $a)
-					trigger_error(gTxt('unknown_attribute', array('{att}' => $a)));
-			}
-			return ($out) ? $out : false;
-		}
+	// deprecated, use lAtts instead. Remove in crockery
+	function gAtt(&$atts, $name, $default=NULL) {
+		return isset($atts[$name]) ? $atts[$name] : $default;
+	}
 
 // -------------------------------------------------------------
-	function select_buttons() 
+	function lAtts($pairs, $atts, $warn=1)
+	{
+		global $production_status;
+
+		foreach($pairs as $name => $default)
+		{
+			$out[$name] = isset($atts[$name]) ? $atts[$name] : $default;
+		}
+
+		if ($warn and ($production_status == 'debug' or $production_status == 'testing'))
+		{
+			foreach (array_diff(array_keys($atts), array_keys($pairs)) as $a)
+			{
+				trigger_error(gTxt('unknown_attribute', array('{att}' => $a)));
+			}
+		}
+
+		return ($out) ? $out : false;
+	}
+
+// -------------------------------------------------------------
+	function select_buttons()
 	{
 		return
 		gTxt('select').': '.
@@ -616,13 +666,13 @@ $LastChangedRevision: 2464 $
 		fInput('button','selnone',gTxt('none'),'smallerboxsp','select none','deselectall();').
 		fInput('button','selrange',gTxt('range'),'smallerboxsp','select range','selectrange();');
 	}
-	
+
 // -------------------------------------------------------------
-	function stripSpace($text, $force=0) 
+	function stripSpace($text, $force=0)
 	{
 		global $prefs;
-		if ($force or !empty($prefs['attach_titles_to_permalinks'])) {
-		
+		if ($force or !empty($prefs['attach_titles_to_permalinks']))
+		{
 			$text = sanitizeForUrl($text);
 			if ($prefs['permalink_title_format']) {
 				return strtolower($text);
@@ -633,7 +683,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function sanitizeForUrl($text) 
+	function sanitizeForUrl($text)
 	{
 		// Remove names entities and tags
 		$text = preg_replace("/(^|&\S+;)|(<[^>]*>)/U","",dumbDown($text));
@@ -645,15 +695,15 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function dumbDown($str, $lang=NULL) 
+	function dumbDown($str, $lang=NULL)
 	{
-		$array = array( // nasty, huh?. 
+		$array = array( // nasty, huh?.
 			'&#192;'=>'A','&Agrave;'=>'A','&#193;'=>'A','&Aacute;'=>'A','&#194;'=>'A','&Acirc;'=>'A',
 			'&#195;'=>'A','&Atilde;'=>'A','&#196;'=>'Ae','&Auml;'=>'A','&#197;'=>'A','&Aring;'=>'A',
-			'&#198;'=>'Ae','&AElig;'=>'AE',			
-			'&#256;'=>'A','&#260;'=>'A','&#258;'=>'A',			
+			'&#198;'=>'Ae','&AElig;'=>'AE',
+			'&#256;'=>'A','&#260;'=>'A','&#258;'=>'A',
 			'&#199;'=>'C','&Ccedil;'=>'C','&#262;'=>'C','&#268;'=>'C','&#264;'=>'C','&#266;'=>'C',
-			'&#270;'=>'D','&#272;'=>'D','&#208;'=>'D','&ETH;'=>'D',			
+			'&#270;'=>'D','&#272;'=>'D','&#208;'=>'D','&ETH;'=>'D',
 			'&#200;'=>'E','&Egrave;'=>'E','&#201;'=>'E','&Eacute;'=>'E','&#202;'=>'E','&Ecirc;'=>'E','&#203;'=>'E','&Euml;'=>'E',
 			'&#274;'=>'E','&#280;'=>'E','&#282;'=>'E','&#276;'=>'E','&#278;'=>'E',
 			'&#284;'=>'G','&#286;'=>'G','&#288;'=>'G','&#290;'=>'G',
@@ -678,7 +728,7 @@ $LastChangedRevision: 2464 $
 			'&#372;'=>'W',
 			'&#221;'=>'Y','&Yacute;'=>'Y','&#374;'=>'Y','&#376;'=>'Y',
 			'&#377;'=>'Z','&#381;'=>'Z','&#379;'=>'Z',
-			'&#222;'=>'T','&THORN;'=>'T',			
+			'&#222;'=>'T','&THORN;'=>'T',
 			'&#224;'=>'a','&#225;'=>'a','&#226;'=>'a','&#227;'=>'a','&#228;'=>'ae',
 			'&auml;'=>'ae',
 			'&#229;'=>'a','&#257;'=>'a','&#261;'=>'a','&#259;'=>'a','&aring;'=>'a',
@@ -761,7 +811,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function is_blacklisted($ip, $checks = '') 
+	function is_blacklisted($ip, $checks = '')
 	{
 		global $prefs;
 		if (!$checks) $checks = explode(',', $prefs['spam_blacklists']);
@@ -784,7 +834,30 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function updateSitePath($here) 
+	function is_logged_in($user = '')
+	{
+		$name = substr(cs('txp_login_public'), 10);
+
+		if (!strlen($name) or strlen($user) and $user !== $name)
+		{
+			return FALSE;
+		}
+
+		$rs = safe_row('nonce, name, RealName, email, privs', 'txp_users', "name = '".doSlash($name)."'");
+
+		if ($rs and substr(md5($rs['nonce']), -10) === substr(cs('txp_login_public'), 0, 10))
+		{
+			unset($rs['nonce']);
+			return $rs;
+		}
+		else
+		{
+			return FALSE;
+		}
+	}
+
+// -------------------------------------------------------------
+	function updateSitePath($here)
 	{
 		$here = doSlash($here);
 		$rs = safe_field ("name",'txp_prefs',"name = 'path_to_site'");
@@ -841,7 +914,7 @@ $LastChangedRevision: 2464 $
 // -------------------------------------------------------------
 	function strip_rn($str)
 	{
-      return preg_replace('/[\r\n]/', ' ', $str);
+		return preg_replace('/[\r\n]/', ' ', $str);
 	}
 
 // -------------------------------------------------------------
@@ -925,7 +998,7 @@ $LastChangedRevision: 2464 $
 			if ("phrase" == $type) {
 				if (preg_match('/[][()<>@,;:".\x5C]/', $string)) {
 					$string = '"'. strtr($string, array("\\" => "\\\\", '"' => '\"')) . '"';
-				} 
+				}
 			}
 			elseif ( "text" != $type) {
 				trigger_error( 'Unknown encode_mailheader type', E_USER_WARNING);
@@ -947,7 +1020,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function stripPHP($in) 
+	function stripPHP($in)
 	{
 		return preg_replace("/".chr(60)."\?(?:php)?|\?".chr(62)."/i",'',$in);
 	}
@@ -957,7 +1030,7 @@ $LastChangedRevision: 2464 $
 /**
  * PEDRO:
  * Helper functions for common textpattern event files actions.
- * Code refactoring from original files. Intended to do easy and less error 
+ * Code refactoring from original files. Intended to do easy and less error
  * prone the future build of new textpattern extensions, and to add new
  * events to multiedit forms.
  */
@@ -975,8 +1048,8 @@ $LastChangedRevision: 2464 $
 		return false;
 	}
 
-// ------------------------------------------------------------- 	
- 	function event_change_pageby($name) 
+// -------------------------------------------------------------
+ 	function event_change_pageby($name)
 	{
 		$qty = gps('qty');
 		safe_update('txp_prefs',"val='".doSlash($qty)."'","name='".doSlash($name).'_list_pageby'."'");
@@ -997,7 +1070,7 @@ $LastChangedRevision: 2464 $
 		}
 
 		return '<label for="withselected">'.gTxt('with_selected').'</label>'.sp.
-			selectInput('edit_method', $methods, $method, 1, 
+			selectInput('edit_method', $methods, $method, 1,
 				( ($name == 'list') ? ' id="withselected" onchange="poweredit(this); return false;"' : ' id="withselected"' )
 			).
 			n.eInput($name).
@@ -1037,12 +1110,12 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function since($stamp) 
+	function since($stamp)
 	{
 		$diff = (time() - $stamp);
 		if ($diff <= 3600) {
 			$mins = round($diff / 60);
-			$since = ($mins <= 1) 
+			$since = ($mins <= 1)
 			?	($mins==1)
 				?	'1 '.gTxt('minute')
 				:	gTxt('a_few_seconds')
@@ -1061,13 +1134,13 @@ $LastChangedRevision: 2464 $
 // Calculate the offset between the server local time and the
 // user's selected time zone
 	function tz_offset()
-	{	
+	{
 		global $gmtoffset, $is_dst;
 
 		extract(getdate());
 		$serveroffset = gmmktime(0,0,0,$mon,$mday,$year) - mktime(0,0,0,$mon,$mday,$year);
 		$offset = $gmtoffset - $serveroffset;
-		
+
 		return $offset + ($is_dst ? 3600 : 0);
 	}
 
@@ -1112,7 +1185,7 @@ $LastChangedRevision: 2464 $
 
 		if ($charset != 'UTF-8' and $format != 'since') {
 			$new = '';
-			if (is_callable('iconv')) 
+			if (is_callable('iconv'))
 				$new = @iconv($charset, 'UTF-8', $str);
 
 			if ($new)
@@ -1136,7 +1209,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function myErrorHandler($errno, $errstr, $errfile, $errline) 
+	function myErrorHandler($errno, $errstr, $errfile, $errline)
 	{
 		# error_reporting() returns 0 when the '@' suppression
 		# operator is used
@@ -1232,7 +1305,7 @@ $LastChangedRevision: 2464 $
 		}
 	}
 
-	
+
 // -------------------------------------------------------------
 	function shift_uploaded_file($f, $dest)
 	{
@@ -1246,23 +1319,27 @@ $LastChangedRevision: 2464 $
 		}
 	}
 // -------------------------------------------------------------
-	function upload_get_errormsg($err_code) 
+	function upload_get_errormsg($err_code)
 	{
 		$msg = '';
 		switch ($err_code)
 		{
-				// Value: 0; There is no error, the file uploaded with success. 
-			case UPLOAD_ERR_OK         : $msg = '';break; 
-				// Value: 1; The uploaded file exceeds the upload_max_filesize directive in php.ini. 
+				// Value: 0; There is no error, the file uploaded with success.
+			case UPLOAD_ERR_OK         : $msg = '';break;
+				// Value: 1; The uploaded file exceeds the upload_max_filesize directive in php.ini.
 			case UPLOAD_ERR_INI_SIZE   : $msg = gTxt('upload_err_ini_size');break;
-				// Value: 2; The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form. 
+				// Value: 2; The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.
 			case UPLOAD_ERR_FORM_SIZE  : $msg = gTxt('upload_err_form_size');break;
-				// Value: 3; The uploaded file was only partially uploaded. 
+				// Value: 3; The uploaded file was only partially uploaded.
 			case UPLOAD_ERR_PARTIAL    : $msg = gTxt('upload_err_partial');break;
-				// Value: 4; No file was uploaded. 
+				// Value: 4; No file was uploaded.
 			case UPLOAD_ERR_NO_FILE    : $msg = gTxt('upload_err_no_file');break;
-     			// Value: 6; Missing a temporary folder. Introduced in PHP 4.3.10 and PHP 5.0.3. 
+				// Value: 6; Missing a temporary folder. Introduced in PHP 4.3.10 and PHP 5.0.3.
 			case UPLOAD_ERR_NO_TMP_DIR : $msg = gTxt('upload_err_tmp_dir');break;
+				// Value: 7; Failed to write file to disk. Introduced in PHP 5.1.0.
+			case UPLOAD_ERR_CANT_WRITE : $msg = gTxt('upload_err_cant_write');break;
+				// Value: 8; File upload stopped by extension. Introduced in PHP 5.2.0.
+			case UPLOAD_ERR_EXTENSION  : $msg = gTxt('upload_err_extension');break;
 		}
 		return $msg;
 	}
@@ -1289,11 +1366,11 @@ $LastChangedRevision: 2464 $
 	function build_file_path($base,$path)
 	{
 		$base = rtrim($base,'/\\');
-		$path = ltrim($path,'/\\');		
-		
+		$path = ltrim($path,'/\\');
+
 		return $base.DIRECTORY_SEPARATOR.$path;
-	}	
-	
+	}
+
 // --------------------------------------------------------------
 	function get_author_name($name)
 	{
@@ -1309,7 +1386,7 @@ $LastChangedRevision: 2464 $
 
 
 // --------------------------------------------------------------
-	function EvalElse($thing, $condition) 
+	function EvalElse($thing, $condition)
 	{
 		$f = '@(</?txp:\S+\b.*(?:(?<!br )/)?'.chr(62).')@sU';
 
@@ -1348,7 +1425,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // --------------------------------------------------------------
-	function fetch_form($name) 
+	function fetch_form($name)
 	{
 		static $forms = array();
 
@@ -1387,7 +1464,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // --------------------------------------------------------------
-	function fetch_category_title($name, $type='article') 
+	function fetch_category_title($name, $type='article')
 	{
 		static $cattitles = array();
 
@@ -1413,7 +1490,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function update_comments_count($id) 
+	function update_comments_count($id)
 	{
 		$id = assert_int($id);
 		$thecount = safe_field('count(*)','txp_discuss','parentid='.$id.' and visible='.VISIBLE);
@@ -1423,7 +1500,7 @@ $LastChangedRevision: 2464 $
 	}
 
 // -------------------------------------------------------------
-	function clean_comment_counts($parentids) 
+	function clean_comment_counts($parentids)
 	{
 		$parentids = array_map('assert_int',$parentids);
 		$rs = safe_rows_start('parentid, count(*) as thecount','txp_discuss','parentid IN ('.implode(',',$parentids).') AND visible='.VISIBLE.' group by parentid');
@@ -1522,8 +1599,8 @@ $LastChangedRevision: 2464 $
 	{
 		extract(doSlash(func_get_args()));
 
-    	if (!safe_row("*", 'txp_prefs', "name = '$name'") ) {
-        	return safe_insert('txp_prefs', "
+		if (!safe_row("*", 'txp_prefs', "name = '$name'") ) {
+			return safe_insert('txp_prefs', "
 				name  = '$name',
 				val   = '$val',
 				event = '$event',
@@ -1534,7 +1611,7 @@ $LastChangedRevision: 2464 $
     	} else {
         	return safe_update('txp_prefs', "val = '$val'","name like '$name'");
     	}
-    	return false;
+    		return false;
 	}
 
 // -------------------------------------------------------------
@@ -1615,13 +1692,14 @@ eod;
 			$GLOBALS['txp_error_status'] = $status;
 			$GLOBALS['txp_error_code'] = $code;
 
+			set_error_handler("tagErrorHandler");
 			die(parse($out));
 		}
 		else {
 			$out = preg_replace(array('@<txp:error_status[^>]*/>@', '@<txp:error_message[^>]*/>@'),
 				array($status, $msg),
 				$out);
-			die($out);		
+			die($out);
 		}
 	}
 
@@ -1735,13 +1813,7 @@ eod;
 
 	function do_list($list, $delim = ',')
 	{
-		$list = explode($delim, $list);
-
-		foreach ($list as $key => $value) {
-			$list[$key] = trim($value);
-		}
-
-		return $list;
+		return array_map('trim', explode($delim, $list));
 	}
 
 // -------------------------------------------------------------
@@ -1812,7 +1884,7 @@ eod;
 
 				$t .= '()';
 				}
-				
+
 
 				$out[] = $t;
 			}
@@ -1831,7 +1903,7 @@ eod;
 
 		// Locale identifiers vary from system to system.  The
 		// following code will attempt to discover which identifiers
-		// are available.  We'll need to expand these lists to 
+		// are available.  We'll need to expand these lists to
 		// improve support.
 		// ISO identifiers: http://www.w3.org/WAI/ER/IG/ert/iso639.htm
 		// Windows: http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vclib/html/_crt_language_strings.asp
@@ -1847,25 +1919,30 @@ eod;
 			'es-es' => array('es_ES.UTF-8', 'es_ES', 'esp', 'spanish', 'es_ES.ISO_8859-1'),
 			'et-ee' => array('et_EE.UTF-8', 'et_EE'),
 			'el-gr' => array('el_GR.UTF-8', 'el_GR', 'el', 'gre', 'greek', 'el_GR.ISO_8859-7'),
-			'fr-fr' => array('fr_FR.UTF-8', 'fr_FR', 'fra', 'fre', 'fr', 'french', 'fr_FR.ISO_8859-1'),
 			'fi-fi' => array('fi_FI.UTF-8', 'fi_FI', 'fin', 'fi', 'finnish', 'fi_FI.ISO_8859-1'),
+			'fr-fr' => array('fr_FR.UTF-8', 'fr_FR', 'fra', 'fre', 'fr', 'french', 'fr_FR.ISO_8859-1'),
+			'gl-gz' => array('gl_GZ.UTF-8', 'gl_GZ', 'glg', 'gl', '', ''),
 			'he_il' => array('he_IL.UTF-8', 'he_IL', 'heb', 'he', 'hebrew', 'he_IL.ISO_8859-8'),
-			'hu_hu' => array('hu_HU.UTF-8', 'hu_HU', 'hun', 'hu', 'hungarian', 'hu_HU.ISO8859-2'),
+			'hr-hr' => array('hr_HR.UTF-8', 'hr_HR', 'hr'),
+			'hu-hu' => array('hu_HU.UTF-8', 'hu_HU', 'hun', 'hu', 'hungarian', 'hu_HU.ISO8859-2'),
 			'id-id' => array('id_ID.UTF-8', 'id_ID', 'id', 'ind', 'indonesian','id_ID.ISO_8859-1'),
 			'is-is' => array('is_IS.UTF-8', 'is_IS'),
 			'it-it' => array('it_IT.UTF-8', 'it_IT', 'it', 'ita', 'italian', 'it_IT.ISO_8859-1'),
 			'ja-jp' => array('ja_JP.UTF-8', 'ja_JP', 'ja', 'jpn', 'japanese', 'ja_JP.ISO_8859-1'),
-			'lv-lv' => array('lv_LV.UTF-8', 'lv_LV'),
-			'no-no' => array('no_NO.UTF-8', 'no_NO', 'no', 'nor', 'norwegian', 'no_NO.ISO_8859-1'),
+			'ko-kr' => array('ko_KR.UTF-8', 'ko_KR', 'ko', 'kor', 'korean'),
+			'lv-lv' => array('lv_LV.UTF-8', 'lv_LV', 'lv', 'lav'),
 			'nl-nl' => array('nl_NL.UTF-8', 'nl_NL', 'dut', 'nla', 'nl', 'nld', 'dutch', 'nl_NL.ISO_8859-1'),
-			'pl-pl' => array('pl_PL.UTF-8', 'pl_PL'),
+			'no-no' => array('no_NO.UTF-8', 'no_NO', 'no', 'nor', 'norwegian', 'no_NO.ISO_8859-1'),
+			'pl-pl' => array('pl_PL.UTF-8', 'pl_PL', 'pl', 'pol', 'polish', ''),
+			'pt-br' => array('pt_BR.UTF-8', 'pt_BR', 'pt', 'ptb', 'portuguese-brazil', ''),
 			'pt-pt' => array('pt_PT.UTF-8', 'pt_PT', 'por', 'portuguese', 'pt_PT.ISO_8859-1'),
 			'ro-ro' => array('ro_RO.UTF-8', 'ro_RO', 'ron', 'rum', 'ro', 'romanian', 'ro_RO.ISO8859-2'),
 			'ru-ru' => array('ru_RU.UTF-8', 'ru_RU', 'ru', 'rus', 'russian', 'ru_RU.ISO8859-5'),
 			'sk-sk' => array('sk_SK.UTF-8', 'sk_SK', 'sk', 'slo', 'slk', 'sky', 'slovak', 'sk_SK.ISO_8859-1'),
 			'sv-se' => array('sv_SE.UTF-8', 'sv_SE', 'sv', 'swe', 'sve', 'swedish', 'sv_SE.ISO_8859-1'),
 			'th-th' => array('th_TH.UTF-8', 'th_TH', 'th', 'tha', 'thai', 'th_TH.ISO_8859-11'),
-			'uk-ua' => array('uk_UA.UTF-8', 'uk_UA'),
+			'uk-ua' => array('uk_UA.UTF-8', 'uk_UA', 'uk', 'ukr'),
+			'vi-vn' => array('vi_VN.UTF-8', 'vi_VN', 'vi', 'vie'),
 			'zh-cn' => array('zh_CN.UTF-8', 'zh_CN'),
 			'zh-tw' => array('zh_TW.UTF-8', 'zh_TW'),
 		);
@@ -1919,7 +1996,7 @@ eod;
 		if (($production_status == 'debug') || (txpinterface == 'admin')) {
 			trigger_error("<pre>Error: '".htmlspecialchars($myvar)."' is not an integer</pre>".
 						  "\n".'<pre style="padding-left: 2em;" class="backtrace"><code>'.
-						  escape_output(join("\n", get_caller(5,1))).'</code></pre>', E_USER_WARNING);
+						  htmlspecialchars(join("\n", get_caller(5,1))).'</code></pre>', E_USER_WARNING);
 		} else trigger_error("'".htmlspecialchars($myvar)."' is not an integer.", E_USER_WARNING);
 		return false;
 	}
@@ -1935,8 +2012,9 @@ eod;
 			$html = preg_replace('@(<img[^>]+src=")/@','$1'.PROTOCOL.serverSet('HTTP_HOST').'/',$html);
 		}
 		# "foo/bar" - relative to the textpattern root
-		$html = preg_replace('@(<a[^>]+href=")(?!http://)@','$1'.PROTOCOL.$siteurl.'/$2',$html);
-		$html = preg_replace('@(<img[^>]+src=")(?!http://)@','$1'.PROTOCOL.$siteurl.'/$2',$html);
+		# leave "http:", "mailto:" et al. as absolute urls
+		$html = preg_replace('@(<a[^>]+href=")(?!\w+:)@','$1'.PROTOCOL.$siteurl.'/$2',$html);
+		$html = preg_replace('@(<img[^>]+src=")(?!\w+:)@','$1'.PROTOCOL.$siteurl.'/$2',$html);
 
 		if ($permalink)
 			$html = preg_replace("/href=\\\"#(.*)\"/","href=\"".$permalink."#\\1\"",$html);
