@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/lib/txplib_wrapper.php $
-$LastChangedRevision: 2286 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/txplib_wrapper.php $
+$LastChangedRevision: 2800 $
 */
 
 /**
@@ -14,12 +14,13 @@ $LastChangedRevision: 2286 $
  * 
  * @link http://txp.kusor.com/wrapper
  * @author Pedro Palazon - http://kusor.net/
- * @copyright 2005-2006 The Textpattern Development Team - http://textpattern.com
+ * @copyright 2005-2008 The Textpattern Development Team - http://textpattern.com
  */
 
 # This class requires to include some Textpattern files in order to work properly.
 # See RPC Server implementation to view an example of the required files and predefined variables.
 
+if (!defined('txpath')) die('txpath is undefined.');
 include_once txpath.'/include/txp_auth.php';
 # Include constants.php?
 if (!defined('LEAVE_TEXT_UNTOUCHED')) define('LEAVE_TEXT_UNTOUCHED', 0);
@@ -96,17 +97,21 @@ class TXP_Wrapper
 	 * @param string $where SQL condition to match
 	 * @param string $offset SQL offset
 	 * @param string $limit SQL limit
+	 * @param boolean $slash escape SQL column names and condition	 
 	 * @return mixed array on success, false on failure	 	 	 
 	 */
-	function getArticleList($what='*', $where='1', $offset='0', $limit='10')
+	function getArticleList($what='*', $where='1', $offset='0', $limit='10', $slash=true)
 	{
 		
 		if ($this->loggedin && has_privs('article.edit.own', $this->txp_user))
 		{
 			$offset = assert_int($offset); 
 			$limit = assert_int($limit);
-			$where = doSlash($where);
-			$what = doSlash($what);
+
+			if ($slash) {
+				$where = doSlash($where);
+				$what = doSlash($what);
+			}
 			
 			if (has_privs('article.edit', $this->txp_user)) {
 				$rs = safe_rows_start($what, 'textpattern', $where." order by Posted desc LIMIT $offset, $limit");
@@ -130,19 +135,24 @@ class TXP_Wrapper
 	/**
 	 * Retrieves an article matching the given criteria
 	 * @param string $what SQL column names to retrieve
-	 * @param string $where SQL condition to match	 
+	 * @param string $where SQL condition to match
+	 * @param boolean $slash escape SQL column names and condition	 
 	 * @return mixed array on success, false on failure	 
 	 */	
-	function getArticle($what='*', $where='1')
+	function getArticle($what='*', $where='1', $slash=true)
 	{
 		if ($this->loggedin && has_privs('article.edit.own', $this->txp_user))
 		{
+			if ($slash) {
+				$what  = doSlash($what);
+				$where = doSlash($where);
+			}
 			// Higer user groups should be able to edit any article
 			if (has_privs('article.edit', $this->txp_user)) {
-				return safe_row(doSlash($what), 'textpattern', doSlash($where));
+				return safe_row($what, 'textpattern', $where);
 			}else {
 				// While restricted users should be able to edit their own articles only
-				return safe_row(doSlash($what), 'textpattern', doSlash($where)." AND AuthorID='".doSlash($this->txp_user)."'");
+				return safe_row($what, 'textpattern', $where." AND AuthorID='".doSlash($this->txp_user)."'");
 			}			
 		}
 		return false;
@@ -266,7 +276,7 @@ class TXP_Wrapper
 		return false;
 	}
 	/**
-	 * Get one category
+	 * Get one category by category name
 	 * @param string $name the category name
 	 * @return mixed array on success, false on failure	 	 
 	 */	
@@ -280,10 +290,10 @@ class TXP_Wrapper
 		return false;
 	}
 	/**
-	 * Same thing, but using category id
-	 * @param mixed(string|integer) $id category id	 
-	 * @return mixed array on success, false on failure	 	 
-	 */	
+	 * Get one category by category id
+	 * @param mixed(string|integer) $id category id
+	 * @return mixed array on success, false on failure
+	 */
 	function getCategoryID($id)
 	{
 		if ($this->loggedin && has_privs('article', $this->txp_user))
@@ -293,6 +303,20 @@ class TXP_Wrapper
 		}
 		return false;
 	}
+	/**
+	 * Get one category by category title
+	 * @param string $title the category title
+	 * @return mixed array on success, false on failure
+	 */
+	function getCategoryTitle($title)
+	{
+		if ($this->loggedin && has_privs('article', $this->txp_user))
+		{
+			$title = doSlash($title);
+			return safe_row('*', 'txp_category',"title='$title' AND type='article'");
+		}
+		return false;
+	}
 	//Get full information for current user
 	/**
 	 * Get full information for current user
@@ -406,16 +430,6 @@ class TXP_Wrapper
 		//All validation rules assumed to be passed before this point.
 		//Do content processing here
 		
-		$incoming = $this->_check_keys($incoming, 
-			array(
-				'AuthorID' => $this->txp_user,
-				'Annotate' => $comments_on_default,
-				'AnnotateInvite' => $comments_default_invite,
-				'textile_body' => $use_textile,
-				'textile_excerpt' => $use_textile
-			)
-		);
-		
 		
 		$incoming_with_markup = $this->textile_main_fields($incoming, $use_textile);
 		
@@ -464,8 +478,6 @@ class TXP_Wrapper
 				}								
 				
 			}else{				
-
-				if (empty($incoming['url_title'])) $incoming['url_title'] = stripSpace($incoming['Title']);
 				//Status should be defined previously. Be sure of that.				
 				if (!has_privs('article.publish', $this->txp_user) && $incoming['Status']==4) $incoming['Status'] = 3;
 			}
@@ -475,6 +487,17 @@ class TXP_Wrapper
 				$incoming['Section'] = safe_field('Section','textpattern',"ID = $article_id");
 			}
 			
+			$incoming = $this->_check_keys($incoming, 
+				array(
+					'AuthorID' => $this->txp_user,
+					'Annotate' => $comments_on_default,
+					'AnnotateInvite' => $comments_default_invite,
+					'textile_body' => $use_textile,
+					'textile_excerpt' => $use_textile,
+					'url_title' => stripSpace($incoming['Title'])
+				)
+			);
+		
 			//Build the SQL query
 			$sql = array();
 			
@@ -583,7 +606,6 @@ class TXP_Wrapper
 	 */
 	function _check_keys($incoming, $default = array())
 	{				
-		
 		$out = array();
 		# strip off unsuited keys
 		foreach ($incoming as $key => $val)
@@ -602,7 +624,7 @@ class TXP_Wrapper
 				$out[$def_key] = '';
 			}
 			# setup the provided default value, if any, only when the incoming value is empty
-			if (array_key_exists($def_key, $default) && $out[$def_key]!==0)
+			if (array_key_exists($def_key, $default) && empty($out[$def_key]))
 			{
 				$out[$def_key] = $default[$def_key];
 			}
@@ -622,24 +644,25 @@ class TXP_Wrapper
 	{
 		global $txpcfg;
 		
-		include_once $txpcfg['txpath'].'/lib/classTextile.php';
+		include_once txpath.'/lib/classTextile.php';
 		$textile = new Textile();
-		
+
 		if (!empty($event) and $event == 'article') 
 		{
 			$incoming['Title_plain'] = $incoming['Title'];
 		}
-		
+
 		if ($incoming['textile_body'] == USE_TEXTILE) 
 		{
 			$incoming['Title'] = $textile->TextileThis($incoming['Title'],'',1);
 		}
-		
-		
+
+		$incoming['url_title'] = preg_replace('|[\x00-\x1f#%+/?\x7f]|', '', $incoming['url_title']);
+
 		$incoming['Body_html'] = TXP_Wrapper::format_field($incoming['Body'],$incoming['textile_body'],$textile);
-		
+
 		$incoming['Excerpt_html'] = TXP_Wrapper::format_field($incoming['Excerpt'],$incoming['textile_excerpt'],$textile);
-		
+
 		return $incoming;
 	}
 
