@@ -8,28 +8,28 @@
     /      |_______________________________________|      \
    /___________)                               (___________\
 
-	Copyright 2005 by Dean Allen 
+	Copyright 2005 by Dean Allen
 	All rights reserved.
 
-	Use of this software denotes acceptance of the Textpattern license agreement 
+	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/publish.php $
-$LastChangedRevision: 2436 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish.php $
+$LastChangedRevision: 2777 $
 
 */
 
 	if (!defined('txpath'))
 		define("txpath", dirname(__FILE__));
-	if (!defined("txpinterface"))	
+	if (!defined("txpinterface"))
 		die('If you just updated and expect to see your site here, please also update the files in your main installation directory.'.
 			' (Otherwise note that publish.php cannot be called directly.)');
 
 
 	include_once txpath.'/lib/constants.php';
+	include_once txpath.'/lib/txplib_misc.php';
 	include_once txpath.'/lib/txplib_db.php';
 	include_once txpath.'/lib/txplib_html.php';
 	include_once txpath.'/lib/txplib_forms.php';
-	include_once txpath.'/lib/txplib_misc.php';
 	include_once txpath.'/lib/admin_config.php';
 
 	include_once txpath.'/publish/taghandlers.php';
@@ -40,35 +40,45 @@ $LastChangedRevision: 2436 $
 
 	ob_start();
 
-    	// start the clock for runtime
+		// start the clock for runtime
 	$microstart = getmicrotime();
 
-		// check the size of the url request
-	bombShelter();
-
 		// get all prefs as an array
- 	$prefs = get_prefs();
+	$prefs = get_prefs();
 
- 		// add prefs to globals
+		// add prefs to globals
 	extract($prefs);
 
+	// check the size of the url request
+	bombShelter();
+
 		// set a higher error level during initialization
 	set_error_level(@$production_status == 'live' ? 'testing' : @$production_status);
 
 		// use the current URL path if $siteurl is unknown
 	if (empty($siteurl))
 		$prefs['siteurl'] = $siteurl = $_SERVER['HTTP_HOST'] . rtrim(dirname($_SERVER['SCRIPT_NAME']), '/');
-	
+
 	if (empty($path_to_site))
 		updateSitePath(dirname(dirname(__FILE__)));
 
-	if (!defined( 'PROTOCOL'))
-		define( 'PROTOCOL', ( ( serverSet('HTTPS') != '' ) ? 'https://' : 'http://') );
-		
-		// v1.0: this should be the definitive http address of the site	
+	if (!defined('PROTOCOL')) {
+		switch (serverSet('HTTPS')) {
+			case '':
+			case 'off': // ISAPI with IIS
+				define('PROTOCOL', 'http://');
+			break;
+
+			default:
+				define('PROTOCOL', 'https://');
+			break;
+		}
+	}
+
+		// v1.0: this should be the definitive http address of the site
 	if (!defined('hu'))
 		define("hu",PROTOCOL.$siteurl.'/');
-	
+
 		// v1.0 experimental relative url global
 	if (!defined('rhu'))
 		define("rhu",preg_replace("|^https?://[^/]+|","",hu));
@@ -163,13 +173,13 @@ $LastChangedRevision: 2436 $
 		if (isset($file_error)) {
 			switch($file_error) {
 			case 403:
-				header('HTTP/1.0 403 Forbidden');
+				txp_die(gTxt('403_forbidden'), '403');
 				break;
 			case 404:
-				header('HTTP/1.0 404 File Not Found');
+				txp_die(gTxt('404_not_found'), '404');
 				break;
 			default:
-				header('HTTP/1.0 500 Internal Server Error');
+				txp_die(gTxt('500_internal_server_error'), '500');
 				break;
 			}
 		}
@@ -208,7 +218,7 @@ $LastChangedRevision: 2436 $
 			// some useful vars for taghandlers, plugins
 		$out['request_uri'] = preg_replace("|^https?://[^/]+|i","",serverSet('REQUEST_URI'));
 		$out['qs'] = serverSet('QUERY_STRING');
-			// IIS fix 
+			// IIS fix
 		if (!$out['request_uri'] and serverSet('SCRIPT_NAME'))
 			$out['request_uri'] = serverSet('SCRIPT_NAME').( (serverSet('QUERY_STRING')) ? '?'.serverSet('QUERY_STRING') : '');
 			// another IIS fix
@@ -227,19 +237,19 @@ $LastChangedRevision: 2436 $
 
 			// if messy vars exist, bypass url parsing
 		if (!$out['id'] && !$out['s'] && !(txpinterface=='css') &&! ( txpinterface=='admin') ) {
-			
+
 			// return clean URL test results for diagnostics
 			if (gps('txpcleantest')) {
 				exit(show_clean_test($out));
 			}
 
 			extract(chopUrl($req));
-	
+
 				//first we sniff out some of the preset url schemes
 			if (strlen($u1)) {
 
 				switch($u1) {
-	
+
 					case 'atom':
 						include txpath.'/publish/atom.php'; exit(atom());
 
@@ -250,23 +260,23 @@ $LastChangedRevision: 2436 $
 					// make it multibyte-safe without breaking backwards-compatibility
 					case urldecode(strtolower(urlencode(gTxt('section')))):
 						$out['s'] = (ckEx('section',$u2)) ? $u2 : ''; $is_404 = empty($out['s']); break;
-	
+
 					case urldecode(strtolower(urlencode(gTxt('category')))):
 						$out['c'] = (ckEx('category',$u2)) ? $u2 : ''; $is_404 = empty($out['c']); break;
-	
+
 					case urldecode(strtolower(urlencode(gTxt('author')))):
 						$out['author'] = (!empty($u2)) ? $u2 : ''; break;
 						// AuthorID gets resolved from Name further down
-	
+
 					case urldecode(strtolower(urlencode(gTxt('file_download')))):
 						$out['s'] = 'file_download';
 						$out['id'] = (!empty($u2)) ? $u2 : ''; break;
-					
+
 					default:
 						// then see if the prefs-defined permlink scheme is usable
 						switch ($permlink_mode) {
-			
-							case 'section_id_title': 
+
+							case 'section_id_title':
 								if (empty($u2)) {
 									$out['s'] = (ckEx('section',$u1)) ? $u1 : '';
 									$is_404 = empty($out['s']);
@@ -278,7 +288,7 @@ $LastChangedRevision: 2436 $
 									$is_404 = (empty($out['s']) or empty($out['id']));
 								}
 							break;
-			
+
 							case 'year_month_day_title':
 								if (empty($u2)) {
 									$out['s'] = (ckEx('section',$u1)) ? $u1 : '';
@@ -303,7 +313,7 @@ $LastChangedRevision: 2436 $
 								}
 							break;
 
-							case 'section_title': 
+							case 'section_title':
 								if (empty($u2)) {
 									$out['s'] = (ckEx('section',$u1)) ? $u1 : '';
 									$is_404 = empty($out['s']);
@@ -315,16 +325,16 @@ $LastChangedRevision: 2436 $
 									$is_404 = (empty($out['s']) or empty($out['id']));
 								}
 							break;
-							
-							case 'title_only': 
+
+							case 'title_only':
 								$rs = lookupByTitle($u1);
 								$out['id'] = @$rs['ID'];
-								$out['s'] = (empty($rs['Section']) ? ckEx('section', $u1) : 
+								$out['s'] = (empty($rs['Section']) ? ckEx('section', $u1) :
 										$rs['Section']);
 								$is_404 = empty($out['s']);
 							break;
 
-							case 'id_title': 		
+							case 'id_title':
 								if (is_numeric($u1) && ckExID($u1))
 								{
 									$rs = lookupByID($u1);
@@ -337,7 +347,7 @@ $LastChangedRevision: 2436 $
 									$is_404 = empty($out['s']);
 								}
 							break;
-			
+
 						}
 				}
 			} else {
@@ -358,7 +368,7 @@ $LastChangedRevision: 2436 $
 		if ($out['author'])
 		{
 			$name = urldecode(strtolower(urlencode($out['author'])));
-		
+
 			$name = safe_field('name', 'txp_users', "RealName like '".doSlash($out['author'])."'");
 
 			if ($name)
@@ -378,19 +388,19 @@ $LastChangedRevision: 2436 $
 
 		$out['pg'] = is_numeric($out['pg']) ? intval($out['pg']) : '';
 		$out['id'] = is_numeric($out['id']) ? intval($out['id']) : '';
-		
+
 		if ($out['s'] == 'file_download') {
 			// get id of potential filename
 			if (!is_numeric($out['id'])) {
-				$rs = safe_row("*", "txp_file", "filename='".doSlash($out['id'])."'");
+				$rs = safe_row("*", "txp_file", "filename='".doSlash($out['id'])."' and status = 4");
 			} else {
-				$rs = safe_row("*", "txp_file", 'id='.intval($out['id']));
+				$rs = safe_row("*", "txp_file", 'id='.intval($out['id']).' and status = 4');
 			}
 
 			$out = ($rs)? array_merge($out, $rs) : array('s'=>'file_download','file_error'=> 404);
 			return $out;
 		}
-		
+
 		if (!$is_404)
 			$out['s'] = (empty($out['s'])) ? 'default' : $out['s'];
 		$s = $out['s'];
@@ -402,14 +412,14 @@ $LastChangedRevision: 2436 $
 
 			// by this point we should know the section, so grab its page and css
 		$rs = safe_row("*", "txp_section", "name = '".doSlash($s)."' limit 1");
-		$out['page'] = @$rs['page'];		
+		$out['page'] = @$rs['page'];
 
 		if(is_numeric($id)) {
-			$a = safe_row('*, unix_timestamp(Posted) as uPosted', 'textpattern', 'ID='.intval($id).' and Status = 4');
+			$a = safe_row('*, unix_timestamp(Posted) as uPosted', 'textpattern', 'ID='.intval($id).' and Status in (4,5)');
 			if ($a) {
-				$Posted             = @$a['Posted'];
-				$out['id_keywords'] = @$a['Keywords'];
-				$out['id_author']   = @$a['AuthorID'];
+				$Posted             = $a['Posted'];
+				$out['id_keywords'] = $a['Keywords'];
+				$out['id_author']   = $a['AuthorID'];
 				populateArticleData($a);
 
 				if ($np = getNextPrev($id, $Posted, $s))
@@ -424,7 +434,7 @@ $LastChangedRevision: 2436 $
 		$out['permlink_mode']  = $permlink_mode;
 		$out['sitename']       = $sitename;
 
-		return $out; 
+		return $out;
 
 	}
 
@@ -432,7 +442,7 @@ $LastChangedRevision: 2436 $
 //	the variables passed to it by pretext();
 
 // -------------------------------------------------------------
-	function textpattern() 
+	function textpattern()
 	{
 		global $pretext,$microstart,$prefs,$qcount,$qtime,$production_status,$txptrace,$siteurl,$has_article_tag;
 
@@ -444,7 +454,7 @@ $LastChangedRevision: 2436 $
 			txp_die(gTxt('404_not_found'), '404');
 
 		$html = safe_field('user_html','txp_page',"name='".doSlash($pretext['page'])."'");
-		if (!$html) 
+		if (!$html)
 			txp_die(gTxt('unknown_section'), '404');
 
 		// useful for clean urls with error-handlers
@@ -511,7 +521,7 @@ $LastChangedRevision: 2436 $
 
 // -------------------------------------------------------------
 	function doArticles($atts, $iscustom)
-	{	
+	{
 		global $pretext, $prefs, $txpcfg;
 		extract($pretext);
 		extract($prefs);
@@ -557,7 +567,7 @@ $LastChangedRevision: 2436 $
 			$theAtts['author'] = (!empty($author)? $author: '');
 			$theAtts['month'] = (!empty($month)? $month: '');
 			$theAtts['frontpage'] = ($s && $s=='default')? true: false;
-			$theAtts['excerpted'] = '';			
+			$theAtts['excerpted'] = '';
 		}
 		extract($theAtts);
 
@@ -567,14 +577,16 @@ $LastChangedRevision: 2436 $
 		if (!is_numeric($status))
 			$status = getStatusNum($status);
 		$issticky = ($status == 5);
-			
+
 		//give control to search, if necesary
-		if($q && !$iscustom && !$issticky) {
+		if($q && !$iscustom && !$issticky)
+		{
 			include_once txpath.'/publish/search.php';
+
 			$s_filter = ($searchall ? filterSearch() : '');
-			$q = doSlash($q);
-			$match = ", match (Title,Body) against ('$q') as score";
-			$search = " and (Title rlike '$q' or Body rlike '$q') $s_filter";
+			$q        = doSlash($q);
+			$match    = ", match (Title,Body) against ('$q') as score";
+			$search   = " and (Title rlike '$q' or Body rlike '$q') $s_filter";
 
 			// searchall=0 can be used to show search results for the current section only
 			if ($searchall) $section = '';
@@ -603,11 +615,12 @@ $LastChangedRevision: 2436 $
 		}
 
 		//Building query parts
-		$frontpage = ($frontpage and !$q) ? filterFrontPage() : '';		
-		$category  = (!$category)  ? '' : " and ((Category1='".doSlash($category)."') or (Category2='".doSlash($category)."')) ";
-		$section   = (!$section)   ? '' : " and Section = '".doSlash($section)."'";
+		$frontpage = ($frontpage and (!$q or $issticky)) ? filterFrontPage() : '';
+		$category  = join("','", doSlash(do_list($category)));
+		$category  = (!$category)  ? '' : " and (Category1 IN ('".$category."') or Category2 IN ('".$category."'))";
+		$section   = (!$section)   ? '' : " and Section IN ('".join("','", doSlash(do_list($section)))."')";
 		$excerpted = ($excerpted=='y')  ? " and Excerpt !=''" : '';
-		$author    = (!$author)    ? '' : " and AuthorID = '".doSlash($author)."'";
+		$author    = (!$author)    ? '' : " and AuthorID IN ('".join("','", doSlash(do_list($author)))."')";
 		$month     = (!$month)     ? '' : " and Posted like '".doSlash($month)."%'";
 		$id        = (!$id)        ? '' : " and ID = '".intval($id)."'";
 		switch ($time) {
@@ -618,7 +631,7 @@ $LastChangedRevision: 2436 $
 			default:
 				$time = " and Posted <= now()";
 		}
-			
+
 		$custom = '';
 
 		if ($customFields) {
@@ -633,11 +646,11 @@ $LastChangedRevision: 2436 $
 
 		//Allow keywords for no-custom articles. That tagging mode, you know
 		if ($keywords) {
-			$keys = doSlash(array_map('trim', split(',' ,$keywords)));
+			$keys = doSlash(do_list($keywords));
 			foreach ($keys as $key) {
 				$keyparts[] = "FIND_IN_SET('".$key."',Keywords)";
 			}
-			$keywords = " and (" . join(' or ',$keyparts) . ")"; 
+			$keywords = " and (" . join(' or ',$keyparts) . ")";
 		}
 
 		if ($q and $searchsticky)
@@ -647,7 +660,7 @@ $LastChangedRevision: 2436 $
 		else
 			$statusq = ' and Status = '.intval($status);
 
-		$where = "1" . $statusq. $time.
+		$where = "1=1" . $statusq. $time.
 			$search . $id . $category . $section . $excerpted . $month . $author . $keywords . $custom . $frontpage;
 
 		//do not paginate if we are on a custom list
@@ -655,9 +668,9 @@ $LastChangedRevision: 2436 $
 		{
 			$grand_total = safe_count('textpattern',$where);
 			$total = $grand_total - $offset;
-			$numPages = ceil($total/$pageby);  
+			$numPages = ceil($total/$pageby);
 			$pg = (!$pg) ? 1 : $pg;
-			$pgoffset = $offset + (($pg - 1) * $pageby);	
+			$pgoffset = $offset + (($pg - 1) * $pageby);
 			// send paging info to txp:newer and txp:older
 			$pageout['pg']       = $pg;
 			$pageout['numPages'] = $numPages;
@@ -675,7 +688,7 @@ $LastChangedRevision: 2436 $
 			$pgoffset = $offset;
 		}
 
-		$rs = safe_rows_start("*, unix_timestamp(Posted) as uPosted".$match, 'textpattern', 
+		$rs = safe_rows_start("*, unix_timestamp(Posted) as uPosted".$match, 'textpattern',
 		$where.' order by '.doSlash($sort).' limit '.intval($pgoffset).', '.intval($limit));
 		// get the form name
 		if ($q and !$iscustom and !$issticky)
@@ -685,7 +698,7 @@ $LastChangedRevision: 2436 $
 
 		if ($rs) {
 			$count = 0;
-			
+
 			$articles = array();
 			while($a = nextRow($rs)) {
 				++$count;
@@ -734,7 +747,7 @@ $LastChangedRevision: 2436 $
 			foreach ($rs as $name) {
 				$filters[] = " and Section != '".doSlash($name)."'";
 			}
-			
+
 			$filterFrontPage = join('', $filters);
 		}
 
@@ -742,7 +755,7 @@ $LastChangedRevision: 2436 $
 	}
 
 // -------------------------------------------------------------
-	function doArticle($atts) 
+	function doArticle($atts)
 	{
 		global $pretext,$prefs, $thisarticle;
 		extract($prefs);
@@ -754,16 +767,20 @@ $LastChangedRevision: 2436 $
 			'allowoverride' => '1',
 			'form'          => 'default',
 			'status'        => '4',
-		),$atts, 0));		
+		),$atts, 0));
 
-		if ($status or empty($thisarticle) or $thisarticle['thisid'] != $id) {
+		if ($status and !is_numeric($status))
+		{
+			$status = getStatusNum($status);
+		}
+
+		if (empty($thisarticle) or $thisarticle['thisid'] != $id)
+		{
 			$thisarticle = NULL;
-			if ($status and !is_numeric($status))
-				$status = getStatusNum($status);
 
 			$q_status = ($status ? 'and Status = '.intval($status) : 'and Status in (4,5)');
 
-			$rs = safe_row("*, unix_timestamp(Posted) as uPosted", 
+			$rs = safe_row("*, unix_timestamp(Posted) as uPosted",
 					"textpattern", 'ID = '.intval($id)." $q_status limit 1");
 
 			if ($rs) {
@@ -772,7 +789,8 @@ $LastChangedRevision: 2436 $
 			}
 		}
 
-		if (!empty($thisarticle)) {
+		if (!empty($thisarticle) and $thisarticle['status'] == $status)
+		{
 			extract($thisarticle);
 			$thisarticle['is_first'] = 1;
 			$thisarticle['is_last'] = 1;
@@ -781,16 +799,16 @@ $LastChangedRevision: 2436 $
 
 			$article = parse_form($form);
 
-			if ($use_comments and $comments_auto_append) {
+			if ($use_comments and $comments_auto_append)
+			{
 				$article .= parse_form('comments_display');
 			}
 
-			
-			unset($GLOBALS['thisarticle']);	
+			unset($GLOBALS['thisarticle']);
 
 			return $article;
 		}
-}	
+	}
 
 // -------------------------------------------------------------
 	function article_custom($atts)
@@ -823,6 +841,7 @@ $LastChangedRevision: 2436 $
 		trace_add("[".gTxt('Article')." $ID]");
 		$out['thisid']          = $ID;
 		$out['posted']          = $uPosted;
+		$out['modified']	= $LastMod;
 		$out['annotate']        = $Annotate;
 		$out['comments_invite'] = $AnnotateInvite;
 		$out['authorid']        = $AuthorID;
@@ -836,20 +855,21 @@ $LastChangedRevision: 2436 $
 		$out['comments_count']  = $comments_count;
 		$out['body']            = $Body_html;
 		$out['excerpt']         = $Excerpt_html;
-		$out['override_form']		= $override_form;
+		$out['override_form']   = $override_form;
+		$out['status']          = $Status;
 
 		$custom = getCustomFields();
 		if ($custom) {
 			foreach ($custom as $i => $name)
 				$out[$name] = $rs['custom_' . $i];
 		}
-		
+
 		global $thisarticle;
-		$thisarticle = $out;	
+		$thisarticle = $out;
 	}
 
 // -------------------------------------------------------------
-	function getNeighbour($Posted, $s, $type) 
+	function getNeighbour($Posted, $s, $type)
 	{
 		$type = ($type == '>') ? '>' : '<';
 		$safe_name = safe_pfx('textpattern');
@@ -871,19 +891,6 @@ $LastChangedRevision: 2436 $
 	{
 		static $next, $cache;
 
-		// If next/prev tags are placed before an article tag on a list page, we
-		// have to guess what the current article is
-		if (!$id) {
-			$current = safe_row('ID, Posted', 'textpattern', 
-				'1=1 '.
-				(($s!='' && $s!='default') ? "and Section = '".doSlash($s)."'" : filterFrontPage()).
-				'and Status=4 and Posted < now() order by Posted desc limit 1');
-			if ($current) {
-				$id = $current['ID'];
-				$Posted = $current['Posted'];
-			}
-		}
-
 		if (@isset($cache[$next[$id]]))
 			$thenext = $cache[$next[$id]];
 		else
@@ -909,10 +916,10 @@ $LastChangedRevision: 2436 $
 	}
 
 // -------------------------------------------------------------
-	function lastMod() 
+	function lastMod()
 	{
 		$last = safe_field("unix_timestamp(val)", "txp_prefs", "`name`='lastmod' and prefs_id=1");
-		return gmdate("D, d M Y H:i:s \G\M\T",$last);	
+		return gmdate("D, d M Y H:i:s \G\M\T",$last);
 	}
 
 // -------------------------------------------------------------
@@ -963,14 +970,17 @@ $LastChangedRevision: 2436 $
 			$out = $tag($atts, $thing, $matches[0]);
 		}
 
+		// deprecated, remove in crockery
 		elseif (isset($pretext[$tag]))
 		{
-			$out = escape_output($pretext[$tag]);
+			$out = htmlspecialchars($pretext[$tag]);
+
+			trigger_error(gTxt('deprecated_tag'), E_USER_NOTICE);
 		}
 
 		else
 		{
-			trigger_error(gTxt('unknown_tag', array('{tag}' => $tag)), E_USER_WARNING);
+			trigger_error(gTxt('unknown_tag'), E_USER_WARNING);
 		}
 
 		@--$txptracelevel;
@@ -1020,7 +1030,7 @@ $LastChangedRevision: 2436 $
 		}
 		return $out;
 	}
-	
+
 // -------------------------------------------------------------
 	function buildCustomSql($custom,$pairs)
 	{
@@ -1034,7 +1044,7 @@ $LastChangedRevision: 2436 $
 				}
 			}
 		}
-		return (!empty($out)) ? ' '.join(' ',$out).' ' : false; 
+		return (!empty($out)) ? ' '.join(' ',$out).' ' : false;
 	}
 
 // -------------------------------------------------------------
@@ -1045,53 +1055,53 @@ $LastChangedRevision: 2436 $
 		$num = empty($labels[$status]) ? 4 : $labels[$status];
 		return $num;
 	}
-	
+
 // -------------------------------------------------------------
-	function ckEx($table,$val,$debug='') 
+	function ckEx($table,$val,$debug='')
 	{
 		return safe_field("name",'txp_'.$table,"`name` like '".doSlash($val)."' limit 1",$debug);
 	}
 
 // -------------------------------------------------------------
-	function ckExID($val,$debug='') 
+	function ckExID($val,$debug='')
 	{
 		return safe_row("ID,Section",'textpattern','ID = '.intval($val).' and Status >= 4 limit 1',$debug);
 	}
 
 // -------------------------------------------------------------
-	function lookupByTitle($val,$debug='') 
+	function lookupByTitle($val,$debug='')
 	{
 		return safe_row("ID,Section",'textpattern',"url_title like '".doSlash($val)."' and Status >= 4 limit 1",$debug);
 	}
 // -------------------------------------------------------------
-	function lookupByTitleSection($val,$section,$debug='') 
+	function lookupByTitleSection($val,$section,$debug='')
 	{
 		return safe_row("ID,Section",'textpattern',"url_title like '".doSlash($val)."' AND Section='".doSlash($section)."' and Status >= 4 limit 1",$debug);
-	}	
+	}
 
 // -------------------------------------------------------------
 
-	function lookupByIDSection($id, $section, $debug = '') 
+	function lookupByIDSection($id, $section, $debug = '')
 	{
-		return safe_row('ID, Section', 'textpattern', 
+		return safe_row('ID, Section', 'textpattern',
 			'ID = '.intval($id)." and Section = '".doSlash($section)."' and Status >= 4 limit 1", $debug);
-	}	
+	}
 
 // -------------------------------------------------------------
-	function lookupByID($id,$debug='') 
+	function lookupByID($id,$debug='')
 	{
 		return safe_row("ID,Section",'textpattern','ID = '.intval($id).' and Status >= 4 limit 1',$debug);
 	}
 
 // -------------------------------------------------------------
-	function lookupByDateTitle($when,$title,$debug='') 
+	function lookupByDateTitle($when,$title,$debug='')
 	{
 		return safe_row("ID,Section","textpattern",
 		"posted like '".doSlash($when)."%' and url_title like '".doSlash($title)."' and Status >= 4 limit 1");
 	}
 
 // -------------------------------------------------------------
-	function makeOut() 
+	function makeOut()
 	{
 		foreach(func_get_args() as $a) {
 			$array[$a] = strval(gps($a));
@@ -1100,7 +1110,7 @@ $LastChangedRevision: 2436 $
 	}
 
 // -------------------------------------------------------------
-	function chopUrl($req) 
+	function chopUrl($req)
 	{
 		$req = strtolower($req);
 		//strip off query_string, if present
@@ -1116,5 +1126,5 @@ $LastChangedRevision: 2436 $
 
 		return $o;
 	}
-	
+
 ?>
