@@ -6,8 +6,8 @@
 
 	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/publish/atom.php $
-$LastChangedRevision: 2402 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish/atom.php $
+$LastChangedRevision: 2774 $
 
 */
 
@@ -16,7 +16,8 @@ $LastChangedRevision: 2402 $
 	function atom()
 	{
 		global $thisarticle;
-		set_error_handler('tagErrorHandler');
+		set_error_handler('feedErrorHandler');
+		ob_clean();
 		extract($GLOBALS['prefs']);
 		define("t_texthtml",' type="text/html"');
 		define("t_text",' type="text"');
@@ -35,8 +36,8 @@ $LastChangedRevision: 2402 $
 
 		$pub = safe_row("RealName, email", "txp_users", "privs=1");
 
-		$out[] = tag(escape_output($sitename),'title',t_text);
-		$out[] = tag(escape_output($site_slogan),'subtitle',t_text);
+		$out[] = tag(htmlspecialchars($sitename),'title',t_text);
+		$out[] = tag(htmlspecialchars($site_slogan),'subtitle',t_text);
 		$out[] = '<link'.r_relself.' href="'.pagelinkurl(array('atom'=>1,'area'=>$area,'section'=>$section,'category'=>$category,'limit'=>$limit)).'" />';
 		$out[] = '<link'.r_relalt.t_texthtml.' href="'.hu.'" />';
 		$articles = array();
@@ -54,13 +55,14 @@ $LastChangedRevision: 2402 $
 		$auth[] = tag($pub['RealName'],'name');
 		$auth[] = ($include_email_atom) ? tag(eE($pub['email']),'email') : '';
 		$auth[] = tag(hu,'uri');
-		
+
 		$out[] = tag(n.t.t.join(n.t.t,$auth).n,'author');
+		$out[] = callback_event('atom_head');
 
 		if (!$area or $area=='article') {
-			
+
 			$sfilter = ($section) ? "and Section = '".$section."'" : '';
-			$cfilter = ($category) 
+			$cfilter = ($category)
 				? "and (Category1='".$category."' or Category2='".$category."')":'';
 			$limit = ($limit) ? $limit : $rss_how_many;
 			$limit = intval(min($limit,max(100,$rss_how_many)));
@@ -71,18 +73,18 @@ $LastChangedRevision: 2402 $
 			foreach($frs as $f) $query[] = "and Section != '".doSlash($f)."'";
 			$query[] = $sfilter;
 			$query[] = $cfilter;
-				
+
 			$rs = safe_rows_start(
-				"*, 
-				ID as thisid, 
+				"*,
+				ID as thisid,
 				unix_timestamp(Posted) as uPosted,
 				unix_timestamp(LastMod) as uLastMod",
-				"textpattern", 
+				"textpattern",
 				"Status=4 and Posted <= now() ".
 					join(' ',$query).
-					"order by Posted desc limit $limit" 
+					"order by Posted desc limit $limit"
 			);
-			if ($rs) {	
+			if ($rs) {
 				while ($a = nextRow($rs)) {
 
 					extract($a);
@@ -103,7 +105,7 @@ $LastChangedRevision: 2402 $
 					$e['issued'] = tag(safe_strftime('w3cdtf',$uPosted),'published');
 					$e['modified'] = tag(safe_strftime('w3cdtf',$uLastMod),'updated');
 
-					$escaped_title = escape_output($Title);
+					$escaped_title = htmlspecialchars($Title);
 					$e['title'] = tag($escaped_title.$count,'title',t_html);
 
 					$permlink = permlinkurl($a);
@@ -137,17 +139,17 @@ $LastChangedRevision: 2402 $
 				}
 			}
 		} elseif ($area=='link') {
-		
+
 			$cfilter = ($category) ? "category='".$category."'" : '1';
 			$limit = ($limit) ? $limit : $rss_how_many;
 			$limit = intval(min($limit,max(100,$rss_how_many)));
-		
+
 			$rs = safe_rows_start("*", "txp_link", "$cfilter order by date desc, id desc limit $limit");
 
 			if ($rs) {
 				while ($a = nextRow($rs)) {
 					extract($a);
- 
+
 					$e['title'] = tag(htmlspecialchars($linkname),'title',t_html);
 					$e['content'] = tag(n.htmlspecialchars($description).n,'content',t_html);
 
@@ -247,11 +249,8 @@ $LastChangedRevision: 2402 $
 			$etag = @join("-",$etags);
 
 			if (strstr($hinm, $etag)) {
-				if ($_SERVER['SERVER_PROTOCOL'] == 'HTTP/1.0')
-					header("HTTP/1.0 304 Not Modified");
-				else
-					header("HTTP/1.1 304 Not Modified");
-				exit;
+				txp_status_header('304 Not Modified');
+				exit(0);
 			}
 
 			if ($etag) header('ETag: "'.$etag.'"');
@@ -279,7 +278,7 @@ $LastChangedRevision: 2402 $
 // see the above code for more appropriate ways of handling feed content
 
 	function safe_hed($toUnicode) {
-		
+
 		if (version_compare(phpversion(), "5.0.0", ">=")) {
 			$str =  html_entity_decode($toUnicode, ENT_QUOTES, "UTF-8");
 		} else {
