@@ -4,10 +4,10 @@
 	This is Textpattern
 	Copyright 2005 by Dean Allen - all rights reserved.
 
-	Use of this software denotes acceptance of the Textpattern license agreement 
+	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/publish/comment.php $
-$LastChangedRevision: 2460 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish/comment.php $
+$LastChangedRevision: 2776 $
 
 */
 
@@ -15,7 +15,7 @@ $LastChangedRevision: 2460 $
 	function fetchComments($id)
 	{
 		$rs = safe_rows(
-			"*, unix_timestamp(posted) as time", 
+			"*, unix_timestamp(posted) as time",
 			"txp_discuss", 'parentid='.intval($id).' and visible='.VISIBLE.' order by posted asc'
 		);
 
@@ -52,7 +52,7 @@ $LastChangedRevision: 2460 $
 		return $secret;
 	}
 
-	function commentForm($id, $atts=NULL) 
+	function commentForm($id, $atts=NULL)
 	{
 		global $prefs;
 		extract($prefs);
@@ -151,7 +151,7 @@ $LastChangedRevision: 2460 $
 
 		$textarea = '<textarea id="message" name="'.$n_message.'"'.$msgcols.$msgrows.$msgstyle.
 			' class="txpCommentInputMessage'.(($commentwarn) ? ' comments_error"' : '"').
-			'>'.htmlspecialchars($message).'</textarea>';
+			'>'.htmlspecialchars(substr(trim($message), 0, 65535)).'</textarea>';
 
 		// by default, the submit button is visible but disabled
 		$comment_submit_button = fInput('submit', 'submit', gTxt('submit'), 'button disabled', '', '', '', '', 'txpCommentSubmit', true);
@@ -230,7 +230,7 @@ $LastChangedRevision: 2460 $
 		ob_start('parse');
 		$out = fetch_form('popup_comments');
 		$out = str_replace("<txp:popup_comments />",$discuss,$out);
-		
+
 		return $out;
 
 	}
@@ -248,7 +248,7 @@ $LastChangedRevision: 2460 $
 	}
 
 // -------------------------------------------------------------
-	function destroyCookies() 
+	function destroyCookies()
 	{
 		$cookietime = time()-3600;
 		ob_start();
@@ -263,7 +263,7 @@ $LastChangedRevision: 2460 $
 	function getComment()
 	{
 		// comment spam filter plugins: call this function to fetch comment contents
-		
+
 		$c = psa( array(
 			'parentid',
 			'name',
@@ -312,7 +312,7 @@ $LastChangedRevision: 2460 $
 
 		$ip = serverset('REMOTE_ADDR');
 
-		if (!checkBan($ip)) 
+		if (!checkBan($ip))
 			txp_die(gTxt('you_have_been_banned'), '403');
 
 		$blacklisted = is_blacklisted($ip);
@@ -330,20 +330,20 @@ $LastChangedRevision: 2460 $
 		$web = doSlash(strip_tags(deEntBrackets($web)));
 		$email = doSlash(strip_tags(deEntBrackets($email)));
 
-		$message = trim($message);
+		$message = substr(trim($message), 0, 65535);
 		$message2db = doSlash(markup_comment($message));
 
-		$isdup = safe_row("message,name", "txp_discuss", 
+		$isdup = safe_row("message,name", "txp_discuss",
 			"name='$name' and message='$message2db' and ip='".doSlash($ip)."'");
 
 		if (   ($prefs['comments_require_name'] && !trim($name))
 			|| ($prefs['comments_require_email'] && !trim($email))
 			|| (!trim($message)))
-		{ 
+		{
 			$evaluator -> add_estimate(RELOAD,1); // The error-messages are added in the preview-code
 		}
 
-		if ($isdup) 
+		if ($isdup)
 			$evaluator -> add_estimate(RELOAD,1); // FIXME? Tell the user about dupe?
 
 		if ( ($evaluator->get_result() != RELOAD) && checkNonce($nonce) ) {
@@ -414,9 +414,9 @@ $LastChangedRevision: 2460 $
 								   VISIBLE  => array(),
 								   RELOAD  => array()
 								);
-			$this->status_text = array(	SPAM => gTxt('spam'), 
-									MODERATE => gTxt('unmoderated'), 
-									VISIBLE  => gTxt('visible'), 
+			$this->status_text = array(	SPAM => gTxt('spam'),
+									MODERATE => gTxt('unmoderated'),
+									VISIBLE  => gTxt('visible'),
 									RELOAD  => gTxt('reload')
 								);
 			$this->message = $this->status;
@@ -456,7 +456,7 @@ $LastChangedRevision: 2460 $
 			$file = $prefs['tempdir'].DS.'evaluator_trace.php';
 			if (!file_exists($file)) {
 				$fp = fopen($file,'wb');
-				if ($fp) 
+				if ($fp)
 					fwrite($fp,"<?php return; ?>\n".
 					"This trace-file tracks saved comments. (created ".safe_strftime($prefs['archive_dateformat'],time()).")\n".
 					"Format is: Type; Probability; Message (Type can be -1 => spam, 0 => moderate, 1 => visible)\n\n");
@@ -472,19 +472,19 @@ $LastChangedRevision: 2460 $
 	}
 
 	function &get_comment_evaluator() {
-	    static $instance; 
-	 
+	    static $instance;
+
 	    // If the instance is not there, create one
-	    if(!isset($instance)) { 
-	        $instance = new comment_evaluation(); 
-	    } 
-	    return $instance; 
+	    if(!isset($instance)) {
+	        $instance = new comment_evaluation();
+	    }
+	    return $instance;
 	}
 
 // -------------------------------------------------------------
 	function checkNonce($nonce)
 	{
-		if (!$nonce && !preg_match('#^[a-zA-Z0-9]*$#',$nonce)) 
+		if (!$nonce && !preg_match('#^[a-zA-Z0-9]*$#',$nonce))
 			return false;
 			// delete expired nonces
 		safe_delete("txp_discuss_nonce", "issue_time < date_sub(now(),interval 10 minute)");
@@ -512,10 +512,10 @@ $LastChangedRevision: 2460 $
 		{
 			$Annotate = $thisarticle['annotate'];
 			$uPosted  = $thisarticle['posted'];
-		} 
+		}
 		else
 		{
-			extract(	
+			extract(
 				safe_row(
 					"Annotate,unix_timestamp(Posted) as uPosted",
 						"textpattern", "ID = $id"
@@ -526,7 +526,7 @@ $LastChangedRevision: 2460 $
 		if ($Annotate != 1)
 			return false;
 
-		if($comments_disabled_after) {		
+		if($comments_disabled_after) {
 			$lifespan = ( $comments_disabled_after * 86400 );
 			$timesince = ( time() - $uPosted );
 			return ( $lifespan > $timesince );
@@ -538,11 +538,11 @@ $LastChangedRevision: 2460 $
 // -------------------------------------------------------------
 		function comments_help()
 	{
-		return ('<a id="txpCommentHelpLink" href="http://textile.thresholdstate.com/help-lite/?lang='.LANG.'" onclick="window.open(this.href, \'popupwindow\', \'width=300,height=400,scrollbars,resizable\'); return false;">'.gTxt('textile_help').'</a>');
+		return ('<a id="txpCommentHelpLink" href="http://rpc.textpattern.com/help/index.php?item=textile_comments&language='.LANG.'" onclick="window.open(this.href, \'popupwindow\', \'width=300,height=400,scrollbars,resizable\'); return false;">'.gTxt('textile_help').'</a>');
 	}
 
 // -------------------------------------------------------------
-	function mail_comment($message, $cname, $cemail, $cweb, $parentid, $discussid) 
+	function mail_comment($message, $cname, $cemail, $cweb, $parentid, $discussid)
 	{
 		global $sitename;
 		$parentid = assert_int($parentid);
@@ -552,17 +552,17 @@ $LastChangedRevision: 2460 $
 		extract(safe_row("RealName, email", "txp_users", "name = '".doSlash($AuthorID)."'"));
 
 		$evaluator =& get_comment_evaluator();
-	
-		$out = gTxt('greeting')." $RealName,\r\n\r\n";
-		$out .= str_replace('{title}',$Title,gTxt('comment_recorded'))."\r\n";
-		$out .= permlinkurl_id($parentid)."\r\n";
+
+		$out = gTxt('greeting')." $RealName,".n.n;
+		$out .= str_replace('{title}',$Title,gTxt('comment_recorded')).n;
+		$out .= permlinkurl_id($parentid).n;
 		if (has_privs('discuss', $AuthorID))
-			$out .= hu.'textpattern/index.php?event=discuss&step=discuss_edit&discussid='.$discussid."\r\n";
-		$out .= gTxt('status').": ".$evaluator->get_result('text').'. '.implode(',',$evaluator->get_result_message())."\r\n";
-		$out .= "\r\n";
-		$out .= gTxt('comment_name').": $cname\r\n";
-		$out .= gTxt('comment_email').": $cemail\r\n";
-		$out .= gTxt('comment_web').": $cweb\r\n";
+			$out .= hu.'textpattern/index.php?event=discuss&step=discuss_edit&discussid='.$discussid.n;
+		$out .= gTxt('status').": ".$evaluator->get_result('text').'. '.implode(',',$evaluator->get_result_message()).n;
+		$out .= n;
+		$out .= gTxt('comment_name').": $cname".n;
+		$out .= gTxt('comment_email').": $cemail".n;
+		$out .= gTxt('comment_web').": $cweb".n;
 		$out .= gTxt('comment_comment').": $message";
 
 		$subject = strtr(gTxt('comment_received'),array('{site}' => $sitename, '{title}' => $Title));
@@ -571,7 +571,7 @@ $LastChangedRevision: 2460 $
 	}
 // -------------------------------------------------------------
 	# deprecated, use fInput instead
-	function input($type,$name,$val,$size='',$class='',$tab='',$chkd='') 
+	function input($type,$name,$val,$size='',$class='',$tab='',$chkd='')
 	{
 		$o = array(
 			'<input type="'.$type.'" name="'.$name.'" id="'.$name.'" value="'.$val.'"',
