@@ -6,8 +6,8 @@
 
 	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/publish/rss.php $
-$LastChangedRevision: 2393 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish/rss.php $
+$LastChangedRevision: 2793 $
 
 */
 
@@ -16,7 +16,8 @@ $LastChangedRevision: 2393 $
 	function rss()
 	{
 		global $prefs,$thisarticle;
-		set_error_handler('tagErrorHandler');
+		set_error_handler('feedErrorHandler');
+		ob_clean();
 		extract($prefs);
 
 		extract(doSlash(gpsa(array('category','section','limit','area'))));
@@ -29,9 +30,11 @@ $LastChangedRevision: 2393 $
 		$out[] = tag('http://textpattern.com/?v='.$version, 'generator');
 		$out[] = tag(doSpecial($sitename),'title');
 		$out[] = tag(hu,'link');
+		$out[] = '<atom:link href="'.pagelinkurl(array('rss'=>1,'area'=>$area,'section'=>$section,'category'=>$category,'limit'=>$limit)).'" rel="self" type="application/rss+xml" />';
 		$out[] = tag(doSpecial($site_slogan),'description');
 		$last = fetch('unix_timestamp(val)','txp_prefs','name','lastmod');
 		$out[] = tag(safe_strftime('rfc822',$last),'pubDate');
+		$out[] = callback_event('rss_head');
 
 		$articles = array();
 
@@ -59,7 +62,7 @@ $LastChangedRevision: 2393 $
 				while ($a = nextRow($rs)) {
 					extract($a);
 					populateArticleData($a);
-					
+
 					$cb = callback_event('rss_entry');
 
 					$a['posted'] = $uPosted;
@@ -79,7 +82,7 @@ $LastChangedRevision: 2393 $
 						$count = ($comments_count > 0) ? ' ['.$comments_count.']' : '';
 					} else $count = '';
 
-					$Title = escape_output(strip_tags($Title)).$count;
+					$Title = htmlspecialchars(strip_tags($Title)).$count;
 
 					$thisauthor = get_author_name($AuthorID);
 
@@ -113,7 +116,7 @@ $LastChangedRevision: 2393 $
 			if ($rs) {
 				while ($a = nextRow($rs)) {
 					extract($a);
-					$item = 
+					$item =
 						tag(doSpecial($linkname),'title').n.
 						tag(doSpecial($description),'description').n.
 						tag(doSpecial($url),'link').n.
@@ -205,11 +208,8 @@ $LastChangedRevision: 2393 $
 			$etag = @join("-",$etags);
 
 			if (strstr($hinm, $etag)) {
-				if ($_SERVER['SERVER_PROTOCOL'] == 'HTTP/1.0')
-					header("HTTP/1.0 304 Not Modified");
-				else
-					header("HTTP/1.1 304 Not Modified");
-				exit;
+				txp_status_header('304 Not Modified');
+				exit(0);
 			}
 
 			if ($cutarticles) {
@@ -227,7 +227,7 @@ $LastChangedRevision: 2393 $
 		if ($etag) header('ETag: "'.$etag.'"');
 		return
 			'<?xml version="1.0" encoding="utf-8"?>'.n.
-			'<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:content="http://purl.org/rss/1.0/modules/content/">'.n.
+			'<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:atom="http://www.w3.org/2005/Atom">'.n.
 			tag(join(n,$out),'channel').n.
 			'</rss>';
 	}
