@@ -18,6 +18,7 @@ $en_gb_lang = array(
 		'email_required' => 'Please provide a valid e-mail address.',
 		'error_adding_new_author' => 'Error adding new author.',
 		'freelancer' => 'Freelancer',
+		'login_name' => 'Login',
 		'log_in_at' => 'Login at',
 		'mail_it' => 'Mail it to me',
 		'managing_editor' => 'Managing Editor',
@@ -25,7 +26,13 @@ $en_gb_lang = array(
 		'new_password' => 'New password',
 		'password_changed' => 'Password changed',
 		'password_changed_mailed' => 'Password changed and mailed to {email}.',
+		'password_forgotten' => 'Forgot password?',
 		'password_required' => 'Please provide a new password.',
+		'password_reset' => 'Reset password',
+		'password_reset_button' => 'Reset password',
+		'password_reset_confirmation' => 'Somebody (probably you) has requested to reset your password. Please confirm this reset request by clicking on the link below',
+		'password_reset_confirmation_request' => 'Please confirm your password reset request',
+		'password_reset_confirmation_request_sent' => 'A confirmation message was sent to your e-mail address. <br />Please check your email and follow the instructions.',
 		'password_sent_to' => 'Password sent to',
 		'privileges' => 'Privileges',
 		'publisher' => 'Publisher',
@@ -33,13 +40,15 @@ $en_gb_lang = array(
 		'reset_author_password' => 'Reset author password',
 		'site_administration' => 'Users',
 		'staff_writer' => 'Staff writer',
+		'unknown_author' => 'Unknown author: {name}',
 		'writer' => 'Writer',
 		'your_login_info' => 'Your login info',
 		'your_login_is' => 'Your login is',
 		'your_new_password' => 'Your new password',
 		'your_password_is' => 'Your password is',
 		'you_have_been_registered' => 'You have been registered as a contributor to the site',
-	),'article' => array(
+	),
+	'article' => array(
 		'advanced_options' => 'Advanced Options',
 		'article_day' => 'Day',
 		'article_hour' => 'Hour',
@@ -68,7 +77,8 @@ $en_gb_lang = array(
 		'url_title_is_blank' => '(URL-only title was left blank)',
 		'url_title_is_multiple' => '(The same URL-only title is used by {count} different articles)',
 		'write' => 'Write',
-	),'category' => array(
+	),
+	'category' => array(
 		'article_categories_deleted' => 'Article categories deleted: <strong>{list}</strong>.',
 		'article_category' => 'Article category',
 		'article_category_already_exists' => 'Article category <strong>{name}</strong> already exists.',
@@ -106,14 +116,19 @@ $en_gb_lang = array(
 		'no_categories_exist' => 'None exist.',
 		'no_other_categories_exist' => 'No other categories exist.',
 		'parent' => 'Parent',
-	),'common' => array(
+	),
+	'common' => array(
 		'active' => 'Active',
 		'add' => 'Add',
 		'admin' => 'Admin',
+		'ar-ar' => 'عربي',
+		'ar-dz' => 'عربي',
 		'are_you_sure' => 'Are you sure?',
 		'ascending' => 'Ascending',
 		'auth_required' => 'Authorisation required.',
-		'bad_cookie' => 'Invalid cookie. Please enter login details.',
+		'bad_cookie' => 'Your login session has expired. Please login again.',
+		'bg-bg' => 'Български',
+		'ca-es' => 'Català',
 		'changeauthor' => 'Change author',
 		'changecategory1' => 'Change Category1',
 		'changecategory2' => 'Change Category2',
@@ -123,40 +138,68 @@ $en_gb_lang = array(
 		'confirm_delete_popup' => 'Really delete?',
 		'cookies_must_be_enabled' => 'Browser cookies must be enabled to use Textpattern.',
 		'could_not_log_in' => 'Could not login with that name/password.',
+		'cs-cz' => 'Čeština',
+		'da-dk' => 'Dansk',
+		'de-de' => 'Deutsch',
 		'delete_selected' => 'Delete selected',
 		'descending' => 'Descending',
 		'description' => 'Description',
 		'detail_toggle' => 'Show Detail',
 		'draft' => 'Draft',
+		'el-gr' => 'Ελληνικά',
+		'en-gb' => 'English (Great Britain)',
+		'en-us' => 'English (United States)',
+		'es-es' => 'Español',
+		'et-ee' => 'Eesti',
 		'excerpt' => 'Excerpt',
 		'expired' => 'Expired',
+		'fi-fi' => 'Suomi',
 		'form_not_found' => 'Form not found',
 		'form_not_specified' => 'Form not specified.',
+		'fr-fr' => 'Français',
 		'gd_unavailable' => 'unavailable',
+		'gl-gz' => 'Galego',
 		'greeting' => 'Dear',
+		'he-il' => 'עברית',
 		'hidden' => 'Hidden',
+		'hr-hr' => 'Hrvatski',
+		'hu-hu' => 'Magyar',
+		'id-id' => 'Bahasa Indonesia',
 		'image_category' => 'Category',
+		'is-is' => 'Íslenska',
+		'it-it' => 'Italiano',
+		'ja-jp' => '日本語',
+		'ko-kr' => '한국말 (대한민국)',
 		'lang_dir' => 'ltr',
 		'link_category' => 'Category',
 		'logged_in_as' => 'Logged in as',
 		'login' => 'Login',
-		'login_name' => 'Login',
 		'login_to_textpattern' => 'Login to Textpattern',
 		'logout' => 'Logout',
 		'log_in_button' => 'Login',
+		'lv-lv' => 'Latviešu',
 		'method' => 'Method',
 		'modified' => 'modified',
+		'nl-nl' => 'Nederlands',
+		'no-no' => 'Norsk',
 		'no_results_found' => 'No results found.',
 		'password' => 'Password',
 		'per_page' => 'per page',
+		'pl-pl' => 'Polski',
+		'pt-br' => 'Português (Brasil)',
+		'pt-pt' => 'Português (Portugal)',
 		'range' => 'Range',
 		'restricted_area' => 'Restricted area',
+		'ro-ro' => 'Română',
+		'ru-ru' => 'Русский',
 		'save_new' => 'Save New',
 		'site_slogan' => 'Site slogan',
+		'sk-sk' => 'Slovenčina',
 		'sort_value' => 'Sort Value',
 		'stay_logged_in' => 'Remain logged in with this browser',
 		'sticky' => 'Sticky',
 		'structure' => 'Structure',
+		'sv-se' => 'Svenska',
 		'tab_admin' => 'Admin',
 		'tab_comments' => 'Comments',
 		'tab_content' => 'Content',
@@ -179,6 +222,7 @@ $en_gb_lang = array(
 		'tab_style' => 'Style',
 		'tab_view_site' => 'View Site',
 		'tab_write' => 'Write',
+		'th-th' => 'ไทย',
 		'thumbnail' => 'Thumbnail',
 		'title_body' => 'Title & Body',
 		'txpnl2br' => 'Line Breaks Only',
@@ -190,18 +234,26 @@ $en_gb_lang = array(
 		'txt_quote_double_open' => '“',
 		'txt_quote_single_close' => '’',
 		'txt_quote_single_open' => '‘',
+		'uk-ua' => 'Українська',
+		'upload_err_cant_write' => 'Failed to write file to disk',
+		'upload_err_extension' => 'File upload stopped by PHP extension',
 		'upload_err_form_size' => 'File exceeds the maximum size specified in Textpattern’s preferences',
 		'upload_err_ini_size' => 'File exceeds the upload_max_filesize directive in php.ini',
 		'upload_err_no_file' => 'No file was specified',
 		'upload_err_partial' => 'File was only partially uploaded',
-		'upload_err_tmp_dir' => 'Temporary directory undefined, please update your Advanced Preferences.',
+		'upload_err_tmp_dir' => 'Missing a temporary folder, used by PHP to store uploaded files. Please consult your webhost.
+',
 		'upload_file' => 'Upload file',
 		'use_textile' => 'Use Textile',
+		'vi-vn' => 'Tiếng Việt (Việt Nam)',
 		'viewsite' => 'View Site',
 		'view_per_page' => 'View {page} per page',
 		'visible' => 'Visible',
 		'with_selected' => 'With selected:',
-	),'css' => array(
+		'zh-cn' => '中文(简体)',
+		'zh-tw' => '中文(繁體)',
+	),
+	'css' => array(
 		'add_declaration' => 'add declaration',
 		'add_new_selector' => 'Add new selector',
 		'all_stylesheets' => 'All Styles',
@@ -217,6 +269,7 @@ $en_gb_lang = array(
 		'css_property_value' => 'Property : Value',
 		'css_selector' => 'Selector',
 		'css_updated' => 'Style <strong>{name}</strong> updated.',
+		'css_used_by_section' => 'Style <strong>{name}</strong> not deleted; used by {count} section(s).',
 		'delete_declaration' => 'Delete this declaration',
 		'delete_entire_selector' => 'Delete entire selector',
 		'delete_this_declaration' => 'Delete this declaration',
@@ -233,7 +286,8 @@ $en_gb_lang = array(
 		'style_sheet' => 'Style sheet',
 		'style_sheet_saved' => 'Style sheet saved',
 		'you_are_editing_css' => 'You are editing style',
-	),'diag' => array(
+	),
+	'diag' => array(
 		'active_plugins' => 'Active plugins',
 		'all_checks_passed' => 'All checks passed!',
 		'apache_modules' => 'Apache modules',
@@ -282,7 +336,8 @@ $en_gb_lang = array(
 		'txp_version' => 'Textpattern version',
 		'warn_register_globals_or_update' => 'Your version of PHP has security related risks. Please turn register_globals off or update to a newer PHP version.',
 		'web_domain' => 'Site URL',
-	),'discuss' => array(
+	),
+	'discuss' => array(
 		'article_deleted' => 'Article deleted!',
 		'ban' => 'Ban',
 		'banned_for' => 'Banned For',
@@ -292,6 +347,7 @@ $en_gb_lang = array(
 		'comments_marked_spam' => 'Comments hidden and marked as spam: <strong>{list}</strong>.',
 		'comments_marked_unmoderated' => 'Comments hidden and marked as unmoderated: <strong>{list}</strong>.',
 		'comments_marked_visible' => 'Comments made visible: <strong>{list}</strong>.',
+		'comment_not_found' => 'Comment does not exist, it may have been deleted.',
 		'comment_updated' => 'Comment <strong>{id}</strong> updated.',
 		'confirm_comment_deletion' => 'confirm comment deletion',
 		'date_banned' => 'Date Banned',
@@ -314,7 +370,8 @@ $en_gb_lang = array(
 		'spam' => 'Spam',
 		'unban' => 'Unban',
 		'unmoderated' => 'Unmoderated',
-	),'file' => array(
+	),
+	'file' => array(
 		'condition' => 'Condition',
 		'download' => 'Download',
 		'downloads' => 'Downloads',
@@ -345,10 +402,12 @@ $en_gb_lang = array(
 		'permissions' => 'Permissions',
 		'private' => 'Private',
 		'public' => 'Public',
+		'replace_file' => 'Replace file',
 		'reset' => 'reset',
 		'reset_file_count_failure' => 'Failed to reset file count',
 		'reset_file_count_success' => 'Successfully reset file count',
-	),'form' => array(
+	),
+	'form' => array(
 		'all_forms' => 'All forms',
 		'create_new_form' => 'Create new form',
 		'delete_form_confirmation' => 'confirm form deletion',
@@ -363,7 +422,8 @@ $en_gb_lang = array(
 		'form_updated' => 'Form <strong>{name}</strong> updated.',
 		'list_forms' => 'list forms',
 		'you_are_editing_form' => 'You are editing form',
-	),'image' => array(
+	),
+	'image' => array(
 		'add_magnify_icon' => 'Magnifier',
 		'alt_text' => 'Alternate text',
 		'cannot_write_directory' => 'Cannot write to directory',
@@ -372,6 +432,7 @@ $en_gb_lang = array(
 		'edit_image' => 'Edit Image',
 		'images' => 'Images',
 		'image_deleted' => 'Image <strong>{name}</strong> deleted.',
+		'image_delete_failed' => 'Image <strong>{name}</strong> could not be completely deleted.',
 		'image_name' => 'Image name',
 		'image_save_error' => 'There was a problem saving image data',
 		'image_updated' => 'Image <strong>{name}</strong> updated.',
@@ -381,9 +442,10 @@ $en_gb_lang = array(
 		'keep_square_pixels' => 'Crop',
 		'not_saved' => '<strong>not</strong> saved!',
 		'no_images_recorded' => 'No images recorded.',
-		'only_graphic_files_allowed' => ' .jpg, .gif, .png or .swf graphic files allowed',
+		'only_graphic_files_allowed' => 'Only .jpg, .gif, .png or .swf file types allowed.',
 		'replace_image' => 'Replace image',
 		'save_these_settings_as_default' => 'Save settings as default',
+		'thumbnail_deleted' => 'Thumbnail deleted.',
 		'thumbnail_not_saved' => 'Thumbnail <strong>{id}</strong> <em>not</em> saved!',
 		'thumbnail_saved' => 'Thumbnail <strong>{id}</strong> saved.',
 		'thumb_height' => 'Height',
@@ -392,7 +454,8 @@ $en_gb_lang = array(
 		'upload_dir_perms' => 'directory permissions must be 777',
 		'upload_image' => 'Upload image',
 		'upload_thumbnail' => 'Upload thumbnail',
-	),'import' => array(
+	),
+	'import' => array(
 		'continue' => 'Continue',
 		'database_stuff' => 'Database Data',
 		'import_blogid' => 'Weblog ID',
@@ -407,7 +470,8 @@ $en_gb_lang = array(
 		'import_wpprefix' => 'Tables prefix (if any)',
 		'select_tool' => 'Import from',
 		'txp_import' => 'Import content from other publishing tools',
-	),'link' => array(
+	),
+	'link' => array(
 		'edit_links' => 'Links',
 		'linkcategory' => 'Link Categories',
 		'links' => 'Links',
@@ -420,16 +484,19 @@ $en_gb_lang = array(
 		'link_text' => 'Link text',
 		'link_updated' => 'Link <strong>{name}</strong> updated.',
 		'no_links_recorded' => 'No links recorded.',
-	),'list' => array(
+	),
+	'list' => array(
 		'article_modified' => 'Modified',
 		'manage' => 'Manage',
-	),'log' => array(
+	),
+	'log' => array(
 		'logs' => 'Logs',
 		'logs_deleted' => 'Logs deleted: <strong>{list}</strong>.',
 		'no_refers_recorded' => 'No referrers recorded.',
 		'referrer' => 'Referrer',
 		'visitor_logs' => 'Visitor Logs',
-	),'page' => array(
+	),
+	'page' => array(
 		'all_pages' => 'All Pages',
 		'copy_page_as' => '…or, copy page as',
 		'create_new_page' => 'Create new page',
@@ -446,10 +513,12 @@ $en_gb_lang = array(
 		'page_name_invalid' => 'Page name is invalid',
 		'page_nav_hed' => 'Site Navigation',
 		'page_updated' => 'Page <strong>{name}</strong> updated.',
+		'page_used_by_section' => 'Page <strong>{name}</strong> not deleted; used by {count} section(s).',
 		'page_xml_hed' => 'XML Feeds',
 		'you_are_editing_div' => 'You are editing div',
 		'you_are_editing_page' => 'You are editing page template',
-	),'plugin' => array(
+	),
+	'plugin' => array(
 		'bad_plugin_code' => 'Badly formed or empty plugin code.',
 		'broken_plugin' => 'broken',
 		'edit_plugins' => 'Plugins',
@@ -459,6 +528,7 @@ $en_gb_lang = array(
 		'old_plugin' => 'Old-style (text file) plugin installer',
 		'plugin' => 'Plugin',
 		'plugins' => 'Plugins',
+		'plugin_compression_unsupported' => 'Plugin decompression is not supported by your server. Contact the plugin author for an uncompressed version.',
 		'plugin_deleted' => 'Plugin <strong>{name}</strong> deleted.',
 		'plugin_help' => 'Plugin Help',
 		'plugin_installed' => 'Plugin <strong>{name}</strong> installed.',
@@ -467,7 +537,8 @@ $en_gb_lang = array(
 		'plugin_saved' => 'Plugin <strong>{name}</strong> updated.',
 		'plugin_updated' => 'Plugin <strong>{name}</strong> updated.',
 		'previewing_plugin' => 'Previewing plugin:',
-	),'prefs' => array(
+	),
+	'prefs' => array(
 		'active_language' => 'Currently active language',
 		'admin_side_plugins' => 'Use admin-side plugins?',
 		'advanced_preferences' => 'Advanced',
@@ -489,7 +560,7 @@ $en_gb_lang = array(
 		'comments_dateformat' => 'Comments date format',
 		'comments_default_invite' => 'Default invite',
 		'comments_disabled_after' => 'Disabled after',
-		'comments_disallow_images' => 'Disallow user images?',
+		'comments_disallow_images' => 'Strip user images?',
 		'comments_mode' => 'Comments mode',
 		'comments_moderate' => 'Moderate comments?',
 		'comments_on_default' => 'On by default?',
@@ -547,7 +618,7 @@ $en_gb_lang = array(
 		'max_url_len' => 'Maximum URL length (in characters)',
 		'mentions' => 'Mentions',
 		'messy' => '?=messy',
-		'never_display_email' => 'Never display e-mail address?',
+		'never_display_email' => 'Hide e-mail address?',
 		'new_textpattern_version_available' => 'There is a completely new Textpattern version available. Do you want to try it?',
 		'norwegian' => 'Norwegian',
 		'no_popup' => 'current window',
@@ -555,7 +626,7 @@ $en_gb_lang = array(
 		'page_mode' => 'Page mode',
 		'path_from_root' => 'Sub-directory (if any)',
 		'path_to_site_missing' => '$path_to_site is not set (update index.php)',
-		'permalink_title_format' => 'Permalink title-like-this (default is TitleLikeThis)?',
+		'permalink_title_format' => 'Permalink title-like-this (instead of TitleLikeThis)?',
 		'permlink_mode' => 'Permanent link mode',
 		'ping_textpattern_com' => 'Ping textpattern.com?',
 		'ping_weblogsdotcom' => 'Ping ping-o-matic.com?',
@@ -569,6 +640,7 @@ $en_gb_lang = array(
 		'production_live' => 'Live',
 		'production_status' => 'Production Status',
 		'production_test' => 'Testing',
+		'publish_expired_articles' => 'Publish expired articles?',
 		'record_mentions' => 'Record mentions',
 		'referrers_only' => 'Referrers only',
 		'rpc_connect_error' => 'Can’t connect to remote server to check for updated language files. Please try again later.',
@@ -602,14 +674,13 @@ $en_gb_lang = array(
 		'use_mail_on_feeds_id' => 'Use e-mail address to construct feed ids (default is site URL)?',
 		'use_plugins' => 'Use plugins?',
 		'year_month_day_title' => '/year/month/day/title',
-	),'public' => array(
+	),
+	'public' => array(
 		'404_not_found' => 'The requested resource was not found.',
 		'410_gone' => 'The requested resource is no longer available.',
 		'ago' => 'ago',
 		'all' => 'All',
 		'already_exists' => 'already exists',
-		'ar-ar' => 'عربي',
-		'ar-dz' => 'عربي',
 		'article' => 'article',
 		'articles' => 'Articles',
 		'articles_found' => 'articles found',
@@ -618,11 +689,9 @@ $en_gb_lang = array(
 		'author' => 'Author',
 		'authors' => 'Authors',
 		'a_few_seconds' => 'a few seconds',
-		'bg-bg' => 'Български',
 		'blockquote' => 'Blockquote',
 		'browse' => 'Browse',
 		'bulleted_list' => 'Bulleted list',
-		'ca-es' => 'Català',
 		'caption' => 'Caption',
 		'categories' => 'Categories',
 		'categorize' => 'Categorise',
@@ -636,7 +705,7 @@ $en_gb_lang = array(
 		'comment' => 'comment',
 		'comments' => 'Comments',
 		'comments_closed' => 'Commenting is closed for this article.',
-		'comments_on' => 'comments on',
+		'comments_on' => 'Comments on',
 		'comments_permlink' => 'Permanent link',
 		'comment_comment' => 'Comment',
 		'comment_email' => 'E-mail',
@@ -656,58 +725,43 @@ $en_gb_lang = array(
 		'create' => 'Create',
 		'created' => 'created',
 		'create_new' => 'Create new',
-		'cs-cz' => 'Čeština',
-		'da-dk' => 'Dansk',
 		'date' => 'Date',
 		'dateformat' => 'Date format',
 		'date_case' => 'Date case',
 		'day' => 'day',
 		'days' => 'days',
-		'de-de' => 'Deutsch',
 		'default' => 'Default',
 		'delete' => 'Delete',
 		'deleted' => 'deleted',
 		'deleted_text' => 'deleted text',
+		'deprecated_tag' => 'tag is deprecated',
 		'edit' => 'Edit',
-		'el-gr' => 'Ελληνικά',
 		'email' => 'E-mail',
 		'email_address' => 'E-mail address',
 		'emphasis' => 'emphasis',
-		'en-gb' => 'English (Great Britain)',
-		'en-us' => 'English (United States)',
-		'english' => 'English',
 		'error_article_context' => 'Article tags cannot be used outside an article context',
-		'es-es' => 'Español',
-		'et-ee' => 'Eesti',
+		'error_comment_context' => 'Comment tags cannot be used outside a comment context',
+		'error_file_context' => 'File tags cannot be used outside a file context',
+		'error_link_context' => 'Link tags cannot be used outside a link context',
 		'extensions' => 'Extensions',
-		'fi-fi' => 'Suomi',
 		'foo_bar' => 'Testing for underscores issue',
 		'forget' => 'Forget',
 		'form' => 'Form',
 		'forms' => 'Forms',
-		'fr-fr' => 'Français',
-		'gl-gz' => 'Galego',
 		'go' => 'Go',
 		'go_content' => 'Go to content',
 		'go_nav' => 'Go to navigation',
 		'go_search' => 'Go to search',
 		'go_to' => 'Go to',
-		'he-il' => 'עברית',
 		'header' => 'header',
 		'host' => 'Host',
 		'hour' => 'hour',
 		'hours' => 'hours',
 		'hr' => 'horizontal rule',
-		'HTML' => 'HTML',
-		'hu-hu' => 'Magyar',
 		'hyperlink' => 'hyperlink',
-		'id-id' => 'Bahasa Indonesia',
 		'image' => 'image',
 		'imageurl' => 'imageurl',
 		'inserted_text' => 'inserted text',
-		'is-is' => 'Íslenska',
-		'it-it' => 'Italiano',
-		'ja-jp' => '日本語',
 		'keywords' => 'Keywords',
 		'label' => 'Label',
 		'last_modification' => 'Last Modification',
@@ -718,7 +772,6 @@ $en_gb_lang = array(
 		'list_links' => 'list links',
 		'live' => 'Live',
 		'lowercase' => 'lowercase',
-		'lv-lv' => 'Latviešu',
 		'manual' => 'Manual',
 		'message' => 'Message',
 		'message_deleted' => 'Message deleted',
@@ -734,9 +787,7 @@ $en_gb_lang = array(
 		'never' => 'never',
 		'newer' => 'Newer',
 		'next' => 'Next',
-		'nl-nl' => 'Nederlands',
 		'no' => 'No',
-		'no-no' => 'Norsk',
 		'none' => 'None',
 		'nopopup' => 'nopopup',
 		'numeric_list' => 'Numeric list',
@@ -749,7 +800,6 @@ $en_gb_lang = array(
 		'paragraph' => 'paragraph',
 		'permanent_link' => 'Permanent link to this article',
 		'permlink' => 'Permanent link',
-		'pl-pl' => 'Polski',
 		'plugin_load_error' => 'A problem occured while loading the plugin:',
 		'plugin_load_error_above' => 'The above errors were caused by the plugin:',
 		'popup' => 'popup',
@@ -758,7 +808,6 @@ $en_gb_lang = array(
 		'posted_by' => 'Posted by',
 		'prev' => 'Prev',
 		'preview' => 'Preview',
-		'pt-pt' => 'Português',
 		'publish' => 'Publish',
 		'published_at' => 'Published at',
 		'raw_php_deprecated' => 'Raw PHP tags are deprecated',
@@ -767,9 +816,7 @@ $en_gb_lang = array(
 		'recent_posts' => 'Recent Posts',
 		'remember' => 'Remember',
 		'revert' => 'Revert',
-		'ro-ro' => 'Română',
 		'rss_feed_title' => 'RSS Feed',
-		'ru-ru' => 'Русский',
 		'save' => 'Save',
 		'saved' => 'saved',
 		'save_button' => 'Save',
@@ -780,29 +827,30 @@ $en_gb_lang = array(
 		'site' => 'Site',
 		'sitename' => 'Site name',
 		'siteurl' => 'Site URL',
-		'sk-sk' => 'Slovenčina',
+		'sp-rs' => 'Srpski',
+		'sr-rs' => 'Српски',
 		'status' => 'Status',
 		'strong' => 'strong',
 		'submit' => 'Submit',
 		'subscript' => 'subscript',
 		'superscript' => 'superscript',
-		'sv-se' => 'Svenska',
 		'syndicate' => 'Syndicate',
+		'tag_error' => 'Tag error: ',
 		'textile_help' => 'Textile Help',
 		'textile_lite_help' => 'Textile Lite Help',
 		'text_conversion' => 'Text conversion',
 		'text_handling' => 'Text handling',
-		'th-th' => 'ไทย',
 		'time' => 'Time',
 		'time_ago' => '{time} ago',
 		'title' => 'Title',
 		'tooltip' => 'Link tooltip',
+		'tr-tr' => 'Türkçe',
 		'type' => 'Type',
-		'uk-ua' => 'Українська',
 		'undefined' => 'Undefined',
 		'unknown_attribute' => 'Unknown tag attribute: {att}',
 		'unknown_image' => 'Unknown image.',
 		'unknown_section' => 'Unknown section',
+		'unknown_tag' => 'tag does not exist',
 		'untitled' => 'Untitled',
 		'update' => 'Update',
 		'upload' => 'Upload',
@@ -819,27 +867,28 @@ $en_gb_lang = array(
 		'your_ip_is_blacklisted_by' => 'Your IP address has been blacklisted by',
 		'you_have_been_banned' => 'You have been banned from commenting.',
 		'yyyy-mm' => 'yyyy-mm',
-		'zh-cn' => '中文(简体)',
-		'zh-tw' => '中文(繁體)',
-	),'section' => array(
+	),
+	'section' => array(
 		'delete_section_confirmation' => 'confirm section deletion',
 		'edit_sections' => 'edit sections',
 		'include_in_search' => 'Include in site search',
 		'on_front_page' => 'On front page',
 		'section' => 'Section',
 		'sections' => 'Sections',
-		'section_created' => 'Section <strong>{name}</strong> created.',
+		'section_created' => 'Section <strong><a href="#section-{name}">{name}</a></strong> created.',
 		'section_deleted' => 'Section <strong>{name}</strong> deleted.',
 		'section_head' => 'Site Sections',
 		'section_longtitle' => 'Section title',
 		'section_name' => 'Section name',
-		'section_name_already_exists' => 'Section <strong>{name}</strong> already exists.',
-		'section_updated' => 'Section <strong>{name}</strong> updated.',
+		'section_name_already_exists' => 'Section <strong><a href="#section-{name}">{name}</a></strong> already exists.',
+		'section_updated' => 'Section <strong><a href="#section-{name}">{name}</a></strong> updated.',
+		'section_used_by_article' => 'Section <strong>{name}</strong> not deleted; used by {count} article(s).',
 		'selected_by_default' => 'Selected by default',
 		'style' => 'Style',
 		'uses_page' => 'Uses page',
 		'uses_style' => 'Uses style',
-	),'setup' => array(
+	),
+	'setup' => array(
 		'about_to_create' => 'You are about to create and populate database tables.',
 		'already_installed' => 'Looks like Textpattern is already installed. If you want to make a clean install, please remove <code>config.php</code> from your <code>/textpattern/</code> directory and try again.',
 		'before_you_proceed' => 'Before you proceed',
@@ -883,7 +932,8 @@ $en_gb_lang = array(
 		'your_email' => 'Your e-mail address',
 		'your_full_name' => 'Your full name',
 		'you_can_access' => 'You should be able to access the <a href="index.php">main interface</a> with the login and password you chose.',
-	),'tag' => array(
+	),
+	'tag' => array(
 		'active_class' => 'CSS class for active list item',
 		'align' => 'Alignment',
 		'allowoverride' => 'Allow form to be overridden?',
@@ -902,11 +952,13 @@ $en_gb_lang = array(
 		'comment_name_link' => 'Link to commenter’s e-mail address/website?',
 		'decimals' => 'Display # numbers after the decimal point',
 		'default_title' => 'Text to use for default section link',
+		'escape' => 'Escape',
 		'exclude' => 'Exclude',
 		'filename' => 'Name',
 		'file_download_tags' => 'File Downloads',
 		'flavor' => 'Syndication format',
 		'flavour' => 'Syndication format',
+		'format' => 'Format',
 		'gmt' => 'Format according to GMT time?',
 		'has_excerpt' => 'Has excerpt',
 		'hilight' => 'Highlight tag',
@@ -934,13 +986,16 @@ $en_gb_lang = array(
 		'no_forms_available' => 'No forms available.',
 		'no_sections_available' => 'No sections available.',
 		'offset' => 'Skip',
+		'pageby' => 'Paginate by',
 		'page_file_hed' => 'File Downloads',
+		'pgonly' => 'Count articles, but show nothing',
 		'random' => 'Random',
 		'rel' => 'Rel XHTML attribute',
 		'searchall' => 'Search all sections?',
 		'searchsticky' => 'Search sticky articles?',
 		'search_input_form' => 'Search input',
 		'search_results_form' => 'Search Results',
+		'showalways' => 'Show always',
 		'showcount' => 'Show count?',
 		'size_format' => 'Size format',
 		'sort' => 'Sort by',
@@ -1035,6 +1090,7 @@ $en_gb_lang = array(
 		'tag_section' => 'Section',
 		'tag_section_list' => 'Section List',
 		'tag_sitename' => 'Site Name',
+		'tag_site_name' => 'Site Name',
 		'tag_site_slogan' => 'Site Slogan',
 		'tag_title' => 'Title',
 		'tag__inline' => 'Inline at beginning',
@@ -1051,5 +1107,5 @@ $en_gb_lang = array(
 		'wraptag' => 'Wrap tag',
 	)
 );
-$lastmod = gmdate('Y-m-d H:m:s',1183270913);
+$lastmod = gmdate('Y-m-d H:m:s',1201802385);
 ?>
