@@ -8,8 +8,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement.
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/setup/index.php $
-$LastChangedRevision: 2069 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/setup/index.php $
+$LastChangedRevision: 2772 $
 
 */
 
@@ -28,7 +28,7 @@ include_once txpath.'/lib/txplib_misc.php';
 
 header("Content-type: text/html; charset=utf-8");
 
-$rel_siteurl = preg_replace('#^(.*)/textpattern[/setuphindx.]*?$#i','\\1',$_SERVER['PHP_SELF']);
+$rel_siteurl = preg_replace('#^(.*)/textpattern.*$#i','\\1',$_SERVER['PHP_SELF']);
 print <<<eod
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 			"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
@@ -36,15 +36,14 @@ print <<<eod
 	<head>
 	<meta http-equiv="content-type" content="text/html; charset=utf-8" />
 	<title>Textpattern &#8250; setup</title>
-	<link rel="Stylesheet" href="$rel_siteurl/textpattern/textpattern.css" type="text/css" />
+	<link rel="stylesheet" href="$rel_siteurl/textpattern/textpattern.css" type="text/css" />
 	</head>
 	<body style="border-top:15px solid #FC3">
 	<div align="center">
 eod;
 
-
-	$step = isPost('step');
-	switch ($step) {	
+	$step = ps('step');
+	switch ($step) {
 		case "": chooseLang(); break;
 		case "getDbInfo": getDbInfo(); break;
 		case "getTxpLogin": getTxpLogin(); break;
@@ -57,10 +56,8 @@ eod;
 </html>
 <?php
 
-// dmp($_POST);
-
 // -------------------------------------------------------------
-	function chooseLang() 
+	function chooseLang()
 	{
 	  echo '<form action="'.$GLOBALS['rel_siteurl'].'/textpattern/setup/index.php" method="post">',
 	  	'<table id="setup" cellpadding="0" cellspacing="0" border="0">',
@@ -76,14 +73,10 @@ eod;
 		'</table></form>';
 	}
 
-
 // -------------------------------------------------------------
-
 	function getDbInfo()
 	{
-		$lang = isPost('lang');
-
-		$GLOBALS['textarray'] = setup_load_lang($lang);
+		$GLOBALS['textarray'] = setup_load_lang(ps('lang'));
 
 		@include txpath.'/config.php';
 
@@ -94,17 +87,21 @@ eod;
 			));
 		}
 
-		$temp_txpath = txpath;
 		if (@$_SERVER['SCRIPT_NAME'] && (@$_SERVER['SERVER_NAME'] || @$_SERVER['HTTP_HOST']))
 		{
 			$guess_siteurl = (@$_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : $_SERVER['SERVER_NAME'];
 			$guess_siteurl .= $GLOBALS['rel_siteurl'];
-		} else $guess_siteurl = 'mysite.com';
-	  echo '<form action="'.$GLOBALS['rel_siteurl'].'/textpattern/setup/index.php" method="post">',
-	  	'<table id="setup" cellpadding="0" cellspacing="0" border="0">',
+		}
+		else
+		{
+			$guess_siteurl = 'mysite.com';
+		}
+
+		echo '<form action="'.$GLOBALS['rel_siteurl'].'/textpattern/setup/index.php" method="post">',
+			'<table id="setup" cellpadding="0" cellspacing="0" border="0">',
 		tr(
 			tda(
-			  hed(gTxt('welcome_to_textpattern'),3). 
+			  hed(gTxt('welcome_to_textpattern'),3).
 			  graf(gTxt('need_details'),' style="margin-bottom:3em"').
 			  hed('MySQL',3).
 			  graf(gTxt('db_must_exist'))
@@ -123,17 +120,6 @@ eod;
 			tdcs(small(gTxt('prefix_warning')),2)
 		),
 		tr(tdcs('&nbsp;',4)),
-		tr(
-			tdcs(
-				hed(gTxt('site_path'),3).
-				graf(gTxt('confirm_site_path')),4)
-		),
-		tr(
-			fLabelCell(gTxt('full_path_to_txp')).
-				tdcs(fInput('text','txpath',$temp_txpath,'edit','','',40).
-				popHelp('full_path'),3)
-		),
-		tr(tdcs('&nbsp;',4)),
 		tr(
 			tdcs(
 				hed(gTxt('site_url'),3).
@@ -144,28 +130,30 @@ eod;
 				tdcs(fInput('text','siteurl',$guess_siteurl,'edit','','',40).
 				popHelp('siteurl'),3)
 		);
+
 		if (!is_callable('mail'))
 		{
-			echo 	tr(
-							tdcs(gTxt('warn_mail_unavailable'),3,null,'" style="color:red;text-align:center')
-					);
-		}
-		echo
-			tr(
-				td().td(fInput('submit','Submit',gTxt('next'),'publish')).td().td()
+			echo tr(
+				tdcs(gTxt('warn_mail_unavailable'),3,null,'" style="color:red;text-align:center')
 			);
+		}
+
+		echo tr(
+			td().td(fInput('submit','Submit',gTxt('next'),'publish')).td().td()
+		);
 		echo endTable(),
-		hInput('lang',$lang),
+		hInput('lang', LANG),
 		sInput('printConfig'),
 		'</form>';
 	}
 
 // -------------------------------------------------------------
-
 	function printConfig()
 	{
-		$carry = enumPostItems('ddb','duser','dpass','dhost','dprefix','txprefix','txpath',
-			'siteurl','ftphost','ftplogin','ftpass','ftpath','lang');
+		$carry = psa(array('ddb','duser','dpass','dhost','dprefix','siteurl','lang'));
+		extract($carry);
+
+		$GLOBALS['textarray'] = setup_load_lang($lang);
 
 		@include txpath.'/config.php';
 
@@ -178,21 +166,17 @@ eod;
 			));
 		}
 
-		$carry['txpath']   = preg_replace("/^(.*)\/$/","$1",$carry['txpath']);
-		$carry['ftpath']   = preg_replace("/^(.*)\/$/","$1",$carry['ftpath']);
-		
-		extract($carry);
-
-		$GLOBALS['textarray'] = setup_load_lang($lang);
 		// FIXME, remove when all languages are updated with this string
 		if (!isset($GLOBALS['textarray']['prefix_bad_characters']))
-			$GLOBALS['textarray']['prefix_bad_characters'] = 
+			$GLOBALS['textarray']['prefix_bad_characters'] =
 				'The Table prefix {dbprefix} contains characters that are not allowed.<br />'.
-				'The first character must match one of <b>a-zA-Z_</b> and all following 
+				'The first character must match one of <b>a-zA-Z_</b> and all following
 				 characters must match one of <b>a-zA-Z0-9_</b>';
 
 		echo graf(gTxt("checking_database"));
-		if (!($mylink = mysql_connect($dhost,$duser,$dpass))){
+
+		if (!($mylink = mysql_connect($dhost,$duser,$dpass)))
+		{
 			exit(graf(gTxt('db_cant_connect')));
 		}
 
@@ -218,19 +202,27 @@ eod;
 
 		// On 4.1 or greater use utf8-tables
 		$version = mysql_get_server_info();
-		if ( intval($version[0]) >= 5 || preg_match('#^4\.[1-9]#',$version)) 
+
+		if ( intval($version[0]) >= 5 || preg_match('#^4\.[1-9]#',$version))
 		{
 			if (mysql_query("SET NAMES utf8"))
 			{
 				$carry['dbcharset'] = "utf8";
-				$carry['dbcollate'] = "utf8_general_ci";
-			} else $carry['dbcharset'] = "latin1";
-		} else $carry['dbcharset'] = "latin1";
+			} 
+			else
+			{
+				$carry['dbcharset'] = "latin1";
+			}
+		}
+		else
+		{
+			$carry['dbcharset'] = "latin1";
+		}
 
 		echo graf(
 			gTxt('using_db', array('{dbname}' => strong($ddb)))
-		.' ('. $carry['dbcharset'] .')' ),
-		
+			.' ('. $carry['dbcharset'] .')' 
+		),
 		graf(
 			strong(gTxt('before_you_proceed')).', '.gTxt('create_config', array('{txpath}' => txpath))
 		),
@@ -245,16 +237,16 @@ eod;
 	}
 
 // -------------------------------------------------------------
-	function getTxpLogin() 
+	function getTxpLogin()
 	{
-		$carry = postDecode(isPost('carry'));
+		$carry = postDecode(ps('carry'));
 		extract($carry);
 
 		$GLOBALS['textarray'] = setup_load_lang($lang);
 
 		@include txpath.'/config.php';
 
-		if (!isset($txpcfg) || ($txpcfg['db'] != $carry['ddb']) || ($txpcfg['txpath'] != $carry['txpath']))
+		if (!isset($txpcfg) || ($txpcfg['db'] != $ddb) || ($txpcfg['table_prefix'] != $dprefix))
 		{
 			echo graf(
 				strong(gTxt('before_you_proceed')).', '.
@@ -262,7 +254,7 @@ eod;
 					'{txpath}' => txpath
 				))
 			),
-	
+
 			'<textarea style="width:400px;height:200px" name="config" rows="1" cols="1">',
 			makeConfig($carry),
 			'</textarea>',
@@ -298,74 +290,55 @@ eod;
 		),
 		endTable(),
 		sInput('createTxp'),
-		hInput('carry',postEncode($carry)),
+		hInput('lang', htmlspecialchars($lang)),
+		hInput('siteurl', htmlspecialchars($siteurl)),
 		'</form>';
 	}
 
 // -------------------------------------------------------------
-
-	function createTxp() 
+	function createTxp()
 	{
-		$email = isPost('email');
+		$GLOBALS['textarray'] = setup_load_lang(ps('lang'));
 
-		if (!is_valid_email($email))
+		if (!is_valid_email(ps('email')))
 		{
 			exit(graf(gTxt('email_required')));
 		}
 
-		$carry = isPost('carry');
-
-		extract(postDecode($carry));
-
 		require txpath.'/config.php';
-		$dbb = $txpcfg['db'];
+		$ddb = $txpcfg['db'];
 		$duser = $txpcfg['user'];
 		$dpass = $txpcfg['pass'];
 		$dhost = $txpcfg['host'];
 		$dprefix = $txpcfg['table_prefix'];
+		$dbcharset = $txpcfg['dbcharset'];
 
-		$GLOBALS['textarray'] = setup_load_lang($lang);
-
-		$siteurl = str_replace("http://",'',$siteurl);
+		$siteurl = str_replace("http://",'', ps('siteurl'));
 		$siteurl = rtrim($siteurl,"/");
-		
+
 		define("PFX",trim($dprefix));
 		define('TXP_INSTALL', 1);
 
-		$name = addslashes(gps('name'));
-
 		include_once txpath.'/lib/txplib_update.php';
  		include txpath.'/setup/txpsql.php';
 
 		// This has to come after txpsql.php, because otherwise we can't call mysql_real_escape_string
-		extract(sDoSlash(gpsa(array('name','pass','RealName','email'))));
+		extract(doSlash(psa(array('name','pass','RealName','email'))));
 
  		$nonce = md5( uniqid( rand(), true ) );
 
 		mysql_query("INSERT INTO `".PFX."txp_users` VALUES
 			(1,'$name',password(lower('$pass')),'$RealName','$email',1,now(),'$nonce')");
 
-		mysql_query("update `".PFX."txp_prefs` set val = '$siteurl' where `name`='siteurl'");
-		mysql_query("update `".PFX."txp_prefs` set val = '$lang' where `name`='language'");
-		mysql_query("update `".PFX."txp_prefs` set val = '".getlocale($lang)."' where `name`='locale'");
+		mysql_query("update `".PFX."txp_prefs` set val = '".doSlash($siteurl)."' where `name`='siteurl'");
+		mysql_query("update `".PFX."txp_prefs` set val = '".LANG."' where `name`='language'");
+		mysql_query("update `".PFX."txp_prefs` set val = '".getlocale(LANG)."' where `name`='locale'");
 
  		echo fbCreate();
 	}
 
-
 // -------------------------------------------------------------
-	function isPost($val)
-	{
-		if(isset($_POST[$val])) {
-			return (MAGIC_QUOTES_GPC) 
-			?	stripslashes($_POST[$val])
-			:	$_POST[$val];						
-		} 
-		return '';
-	}
-
-// -------------------------------------------------------------
-	function makeConfig($ar) 
+	function makeConfig($ar)
 	{
 		define("nl","';\n");
 		define("o",'$txpcfg[\'');
@@ -374,20 +347,19 @@ eod;
 		$close = '?'.chr(62);
 		extract($ar);
 		return
-		$open."\n".
-		o.'db'			  .m.$ddb.nl
-		.o.'user'		  .m.$duser.nl
-		.o.'pass'		  .m.$dpass.nl
-		.o.'host'		  .m.$dhost.nl
+		$open."\n"
+		.o.'db'           .m.$ddb.nl
+		.o.'user'         .m.$duser.nl
+		.o.'pass'         .m.$dpass.nl
+		.o.'host'         .m.$dhost.nl
 		.o.'table_prefix' .m.$dprefix.nl
-		.o.'txpath'		  .m.$txpath.nl
-		.o.'dbcharset'	  .m.$dbcharset.nl
+		.o.'txpath'       .m.txpath.nl   // remove in crockery
+		.o.'dbcharset'    .m.$dbcharset.nl
 		.$close;
 	}
 
 // -------------------------------------------------------------
-
-	function fbCreate() 
+	function fbCreate()
 	{
 		if ($GLOBALS['txp_install_successful'] === false)
 		{
@@ -433,53 +405,52 @@ eod;
 	}
 
 // -------------------------------------------------------------
-	function enumPostItems() 
-	{
-		foreach(func_get_args() as $item) { $out[$item] = isPost($item); }
-		return $out; 
-	}
-
-//-------------------------------------------------------------
-
 	function langs()
 	{
 		$langs = array(
 			'ar-dz' => 'جزائري عربي',
+			'bg-bg' => 'Български',
 			'ca-es' => 'Català',
 			'cs-cz' => 'Čeština',
 			'da-dk' => 'Dansk',
 			'de-de' => 'Deutsch',
 			'el-gr' => 'Ελληνικά',
-			'en-gb' => 'English (GB)',
-			'en-us' => 'English (US)',
+			'en-gb' => 'English (Great Britain)',
+			'en-us' => 'English (United States)',
 			'es-es' => 'Español',
 			'et-ee' => 'Eesti',
 			'fi-fi' => 'Suomi',
 			'fr-fr' => 'Français',
-			'gl-gz' => 'Galego (Galiza)',
+			'gl-gz' => 'Galego',
 			'he-il' => 'עברית',
+			'hr-hr' => 'Hrvatski',
 			'hu-hu' => 'Magyar',
 			'id-id' => 'Bahasa Indonesia',
 			'is-is' => 'Íslenska',
 			'it-it' => 'Italiano',
 			'ja-jp' => '日本語',
+			'ko-kr' => '한국말 (대한민국)',
 			'lv-lv' => 'Latviešu',
 			'nl-nl' => 'Nederlands',
 			'no-no' => 'Norsk',
 			'pl-pl' => 'Polski',
-			'pt-pt' => 'Português',
+			'pt-br' => 'Português (Brasil)',
+			'pt-pt' => 'Português (Portugal)',
 			'ro-ro' => 'Română',
 			'ru-ru' => 'Русский',
 			'sk-sk' => 'Slovenčina',
+			'sp-rs' => 'Srpski',
+			'sr-rs' => 'Српски',
 			'sv-se' => 'Svenska',
 			'th-th' => 'ไทย',
+			'tr-tr' => 'Türkçe',
 			'uk-ua' => 'Українська',
+			'vi-vn' => 'Tiếng Việt (Việt Nam)',
 			'zh-cn' => '中文(简体)',
 			'zh-tw' => '中文(繁體)',
-			'bg-bg' => 'Български'
 		);
 
-		$default	= 'en-gb';
+		$default = 'en-gb';
 
 		$out = n.'<select name="lang">';
 
@@ -496,7 +467,7 @@ eod;
 	}
 
 // -------------------------------------------------------------
-	function setup_load_lang($lang) 
+	function setup_load_lang($lang)
 	{
 		require_once txpath.'/setup/setup-langs.php';
 		$lang = (isset($langs[$lang]) && !empty($langs[$lang]))? $lang : 'en-gb';
@@ -504,15 +475,4 @@ eod;
 		return $langs[LANG];
 	}
 
-// -------------------------------------------------------------
-	function sDoSlash($in)
-	{ 
-		if(phpversion() >= "4.3.0") {
-			return doArray($in,'mysql_real_escape_string');
-		} else {
-			return doArray($in,'mysql_escape_string');
-		}
-	}
-
-
 ?>
