@@ -1,7 +1,7 @@
 <?php
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.5/source/textpattern/update/_update.php $
-$LastChangedRevision: 2470 $
+$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/update/_update.php $
+$LastChangedRevision: 2792 $
 */
 	if (!defined('TXP_UPDATE'))
 		exit("Nothing here. You can't access this file directly.");
@@ -45,30 +45,36 @@ $LastChangedRevision: 2470 $
 			$dbversion = '4.0';
 	}  
 
-	if ( $dbversion !== '4.0.2' )
+	if (version_compare($dbversion, '4.0.2', '<'))
 	{  
 		if ((include txpath.DS.'update'.DS.'_to_4.0.2.php') !== false)
 			$dbversion = '4.0.2';
 	}
 
-	if ( $dbversion !== '4.0.3' )
+	if (version_compare($dbversion, '4.0.3', '<'))
 	{  
 		if ((include txpath.DS.'update'.DS.'_to_4.0.3.php') !== false)
 			$dbversion = '4.0.3';
 	}
 
-	if ( $dbversion !== '4.0.4' )
+	if (version_compare($dbversion, '4.0.4', '<'))
 	{  
 		if ((include txpath.DS.'update'.DS.'_to_4.0.4.php') !== false)
 			$dbversion = '4.0.4';
 	}
 
-	if ( $dbversion !== '4.0.5' )
+	if (version_compare($dbversion, '4.0.5', '<'))
 	{  
 		if ((include txpath.DS.'update'.DS.'_to_4.0.5.php') !== false)
 			$dbversion = '4.0.5';
 	}
- 
+
+	if (version_compare($dbversion, '4.0.6', '<'))
+	{  
+		if ((include txpath.DS.'update'.DS.'_to_4.0.6.php') !== false)
+			$dbversion = '4.0.6';
+	}
+
 	// keep track of updates for svn users
 	safe_delete('txp_prefs',"name = 'dbupdatetime'");
 	safe_insert('txp_prefs', "prefs_id=1, name='dbupdatetime',val='".max(newest_file(),time())."', type='2'");
